/**
 * Copyright (c) 2023 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwell.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwell *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwell_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwell_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwell_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwell();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwell::Heavy_vSwell(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_QgCBhOiQ, &hTable_O064EXeZ);
  numBytes += sTabread_init(&sTabread_VnaxrgnU, &hTable_O064EXeZ, true);
  numBytes += sRPole_init(&sRPole_r2MOTexs);
  numBytes += sEnv_init(&sEnv_DOLGpdX5, 1024, 512);
  numBytes += sLine_init(&sLine_b5IV56ZP);
  numBytes += cSlice_init(&cSlice_M9M1ycfn, 1, -1);
  numBytes += cSlice_init(&cSlice_0JPTBcHK, 1, -1);
  numBytes += cVar_init_f(&cVar_OlalfsVZ, 0.0f);
  numBytes += cIf_init(&cIf_ANJ9cktm, false);
  numBytes += cBinop_init(&cBinop_y0MXYUyq, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_2m3y0thE, 1, -1);
  numBytes += cSlice_init(&cSlice_AGoygqfK, 1, -1);
  numBytes += cVar_init_f(&cVar_GOwP3g4a, 0.0f);
  numBytes += cIf_init(&cIf_yX48XYgl, false);
  numBytes += cBinop_init(&cBinop_DyANiW7g, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_fodKGBqC, 0.0f);
  numBytes += cVar_init_f(&cVar_TCKRK1RG, 0.0f);
  numBytes += cBinop_init(&cBinop_2r1ppDwb, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_7q852oDM, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_0uhnzd30, 2, 1);
  numBytes += cSlice_init(&cSlice_QQi0FUQY, 1, 1);
  numBytes += cSlice_init(&cSlice_scwGuJq0, 0, 1);
  numBytes += cVar_init_f(&cVar_CKy0vAry, 0.0f);
  numBytes += cIf_init(&cIf_Zsus1rnG, false);
  numBytes += cIf_init(&cIf_io6rJh9B, false);
  numBytes += cIf_init(&cIf_yqL1o1zQ, false);
  numBytes += cIf_init(&cIf_cXTVmzn0, false);
  numBytes += cIf_init(&cIf_mpJN0Ufb, false);
  numBytes += cBinop_init(&cBinop_Y1xwSXYf, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_r44dUYoy, 10.0f);
  numBytes += cPack_init(&cPack_mEmPhTVR, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_0afNgaTX, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_dle2F0Ch, 10.0f);
  numBytes += cPack_init(&cPack_F3m35Oqi, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_0dshU9ZO, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_GYNHBu58, 10.0f);
  numBytes += cPack_init(&cPack_fGqFTfRn, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_8H8W6XcH, 1e-07f);
  numBytes += cIf_init(&cIf_GpmcPwAQ, true);
  numBytes += cVar_init_f(&cVar_hz9mze6C, 1e-07f);
  numBytes += cVar_init_f(&cVar_uU4GjvJM, 1e-07f);
  numBytes += sVarf_init(&sVarf_UGiNWJ5x, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_TbHKkOba, 0.0f);
  numBytes += cVar_init_f(&cVar_FU81aU7I, 20.0f);
  numBytes += cBinop_init(&cBinop_9gRYNbUi, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_mmOchhs5, 0.0f);
  numBytes += cSlice_init(&cSlice_ey5NPiU5, 1, -1);
  numBytes += cSlice_init(&cSlice_rOBujmsW, 1, -1);
  numBytes += cVar_init_f(&cVar_MrKm7HQ8, 0.0f);
  numBytes += cVar_init_f(&cVar_tHaSnMd4, 20.0f);
  numBytes += cVar_init_f(&cVar_neRa3rhM, 0.0f);
  numBytes += cVar_init_f(&cVar_FKg6jxRk, 0.0f);
  numBytes += cVar_init_f(&cVar_47P141NJ, 0.0f);
  numBytes += cSlice_init(&cSlice_kaJlBnjY, 1, 1);
  numBytes += cSlice_init(&cSlice_aIV0koXO, 0, 1);
  numBytes += cBinop_init(&cBinop_B1eydAF4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qAK11QYY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_c10UW9fu, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_brBXyLko, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_vwU2zUkj, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_Ah074Epm, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_YyC8wfyP, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ctFA6d7M, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_KNFxKcip, 5.0f);
  numBytes += cVar_init_f(&cVar_5Pi7RuRw, 500.0f);
  numBytes += cBinop_init(&cBinop_t6gJZF4r, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ku0ubf0E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wAyLWKS7, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_WxZLKTTw, 0.0f);
  numBytes += cDelay_init(this, &cDelay_yYL6K3er, 0.0f);
  numBytes += hTable_init(&hTable_O064EXeZ, 256);
  numBytes += cTabhead_init(&cTabhead_wWdFyyIT, &hTable_O064EXeZ);
  numBytes += cVar_init_s(&cVar_9OE6WqUq, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_TvNIk3jT, 8.0f);
  numBytes += cDelay_init(this, &cDelay_LHPvtudF, 0.0f);
  numBytes += cBinop_init(&cBinop_Dj87N7KJ, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_c0jOExdW, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_4DS5XSNo, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_duxBREDs, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_nHxsItMr, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_mOW3O0Ta, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Qw5G04LZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_b9qmX7ee, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwell::~Heavy_vSwell() {
  sEnv_free(&sEnv_DOLGpdX5);
  cPack_free(&cPack_mEmPhTVR);
  cPack_free(&cPack_F3m35Oqi);
  cPack_free(&cPack_fGqFTfRn);
  hTable_free(&hTable_O064EXeZ);
}

HvTable *Heavy_vSwell::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_O064EXeZ; // del-1001-swell
    default: return nullptr;
  }
}

void Heavy_vSwell::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3t4tPjfG_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_blyGw3hm_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9fxRJWtv_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c5OTESlQ_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DNtXTRti_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FqUWDLcg_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GenGUKZ5_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Yuzz8M6Y_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_27wz3v6o_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3TeoH8xW_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_slhNiKL0_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oUHH4I0a_sendMessage);
      break;
    }
    case 0xE7A7BB75: { // Trigger_by_Audio_ON
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2D7N9oVU_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9yf2Rxwm_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lXagAWpq_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_M83nwdAM_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_h7uV2Id5_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwell::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 30.0f;
        info->maxVal = 85.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_by_Audio_ON";
        info->hash = 0xE7A7BB75;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 13;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwell::sEnv_DOLGpdX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2r1ppDwb, HV_BINOP_GREATER_THAN, 0, m, &cBinop_2r1ppDwb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7q852oDM, HV_BINOP_LESS_THAN, 0, m, &cBinop_7q852oDM_sendMessage);
}

void Heavy_vSwell::cSwitchcase_GDEXSwXF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_M9M1ycfn, 0, m, &cSlice_M9M1ycfn_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0JPTBcHK, 0, m, &cSlice_0JPTBcHK_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N05pE5wR_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VHnqtLtv_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_M9M1ycfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_OlalfsVZ, 0, m, &cVar_OlalfsVZ_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_OlalfsVZ, 0, m, &cVar_OlalfsVZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_0JPTBcHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_y0MXYUyq, HV_BINOP_NEQ, 1, m, &cBinop_y0MXYUyq_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_OlalfsVZ, 1, m, &cVar_OlalfsVZ_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_y0MXYUyq, HV_BINOP_NEQ, 1, m, &cBinop_y0MXYUyq_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_OlalfsVZ, 1, m, &cVar_OlalfsVZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_OlalfsVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qPx6sKni_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_ANJ9cktm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wPFUfY8k_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WBtsTXIm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_WBtsTXIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OlalfsVZ, 0, m, &cVar_OlalfsVZ_sendMessage);
}

void Heavy_vSwell::cCast_wPFUfY8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y0MXYUyq, HV_BINOP_NEQ, 1, m, &cBinop_y0MXYUyq_sendMessage);
}

void Heavy_vSwell::cBinop_y0MXYUyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ANJ9cktm, 1, m, &cIf_ANJ9cktm_sendMessage);
}

void Heavy_vSwell::cCast_VHnqtLtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ANJ9cktm, 0, m, &cIf_ANJ9cktm_sendMessage);
}

void Heavy_vSwell::cCast_N05pE5wR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y0MXYUyq, HV_BINOP_NEQ, 0, m, &cBinop_y0MXYUyq_sendMessage);
}

void Heavy_vSwell::cSwitchcase_ji0fs6uB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2m3y0thE, 0, m, &cSlice_2m3y0thE_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AGoygqfK, 0, m, &cSlice_AGoygqfK_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6UhvGjdK_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b62uZ9qb_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_2m3y0thE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_GOwP3g4a, 0, m, &cVar_GOwP3g4a_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_GOwP3g4a, 0, m, &cVar_GOwP3g4a_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_AGoygqfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_DyANiW7g, HV_BINOP_NEQ, 1, m, &cBinop_DyANiW7g_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_GOwP3g4a, 1, m, &cVar_GOwP3g4a_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_DyANiW7g, HV_BINOP_NEQ, 1, m, &cBinop_DyANiW7g_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_GOwP3g4a, 1, m, &cVar_GOwP3g4a_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_GOwP3g4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9QtFjKcG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_yX48XYgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cb6MwJx2_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1qJKZWM8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_1qJKZWM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GOwP3g4a, 0, m, &cVar_GOwP3g4a_sendMessage);
}

void Heavy_vSwell::cCast_Cb6MwJx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DyANiW7g, HV_BINOP_NEQ, 1, m, &cBinop_DyANiW7g_sendMessage);
}

void Heavy_vSwell::cBinop_DyANiW7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yX48XYgl, 1, m, &cIf_yX48XYgl_sendMessage);
}

void Heavy_vSwell::cCast_b62uZ9qb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yX48XYgl, 0, m, &cIf_yX48XYgl_sendMessage);
}

void Heavy_vSwell::cCast_6UhvGjdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DyANiW7g, HV_BINOP_NEQ, 0, m, &cBinop_DyANiW7g_sendMessage);
}

void Heavy_vSwell::cSwitchcase_qPx6sKni_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jsM9VquE_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_miEi7JCY_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_jsM9VquE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TCKRK1RG, 0, m, &cVar_TCKRK1RG_sendMessage);
}

void Heavy_vSwell::cCast_miEi7JCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bzTsfiah_sendMessage(_c, 0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GpmcPwAQ, 0, m, &cIf_GpmcPwAQ_sendMessage);
}

void Heavy_vSwell::cSwitchcase_9QtFjKcG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k1ms7VvX_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7dthoAs6_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_k1ms7VvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fodKGBqC, 0, m, &cVar_fodKGBqC_sendMessage);
}

void Heavy_vSwell::cCast_7dthoAs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_buYAKPhm_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_fodKGBqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2r1ppDwb, HV_BINOP_GREATER_THAN, 1, m, &cBinop_2r1ppDwb_sendMessage);
}

void Heavy_vSwell::cVar_TCKRK1RG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7q852oDM, HV_BINOP_LESS_THAN, 1, m, &cBinop_7q852oDM_sendMessage);
}

void Heavy_vSwell::cBinop_2r1ppDwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GDEXSwXF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_7q852oDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ji0fs6uB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_bzTsfiah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2r1ppDwb, HV_BINOP_GREATER_THAN, 1, m, &cBinop_2r1ppDwb_sendMessage);
}

void Heavy_vSwell::cMsg_buYAKPhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7q852oDM, HV_BINOP_LESS_THAN, 1, m, &cBinop_7q852oDM_sendMessage);
}

void Heavy_vSwell::cSlice_0uhnzd30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_d48MlnsP_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_QQi0FUQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_cXTVmzn0, 0, m, &cIf_cXTVmzn0_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_io6rJh9B, 0, m, &cIf_io6rJh9B_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_scwGuJq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_mpJN0Ufb, 0, m, &cIf_mpJN0Ufb_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_yqL1o1zQ, 0, m, &cIf_yqL1o1zQ_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_CKy0vAry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_cmNZBMC0_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Zsus1rnG, 0, m, &cIf_Zsus1rnG_sendMessage);
}

void Heavy_vSwell::cUnop_RsEotKYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vcN5ARU8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y1xwSXYf, HV_BINOP_EQ, 1, m, &cBinop_Y1xwSXYf_sendMessage);
}

void Heavy_vSwell::cUnop_2w4EsuYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vcN5ARU8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y1xwSXYf, HV_BINOP_EQ, 1, m, &cBinop_Y1xwSXYf_sendMessage);
}

void Heavy_vSwell::cIf_Zsus1rnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_2w4EsuYA_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_RsEotKYI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_cmNZBMC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zsus1rnG, 1, m, &cIf_Zsus1rnG_sendMessage);
}

void Heavy_vSwell::cIf_io6rJh9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_U4oBNoTS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_yqL1o1zQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_cXTVmzn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_U4oBNoTS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_mpJN0Ufb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_d48MlnsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y1xwSXYf, HV_BINOP_EQ, 0, m, &cBinop_Y1xwSXYf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_fN9qgyGJ_sendMessage);
}

void Heavy_vSwell::cBinop_vcN5ARU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CSAhyzs9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_62aJ0NFI_sendMessage);
}

void Heavy_vSwell::cBinop_Y1xwSXYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oTuNvNja_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bQu6acLf_sendMessage);
}

void Heavy_vSwell::cCast_bQu6acLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mpJN0Ufb, 1, m, &cIf_mpJN0Ufb_sendMessage);
}

void Heavy_vSwell::cCast_oTuNvNja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_io6rJh9B, 1, m, &cIf_io6rJh9B_sendMessage);
}

void Heavy_vSwell::cCast_62aJ0NFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yqL1o1zQ, 1, m, &cIf_yqL1o1zQ_sendMessage);
}

void Heavy_vSwell::cCast_CSAhyzs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cXTVmzn0, 1, m, &cIf_cXTVmzn0_sendMessage);
}

void Heavy_vSwell::cBinop_fN9qgyGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwell::cSwitchcase_2WWNLFOg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BW35vMN9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BW35vMN9_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_r44dUYoy, 1, m, &cDelay_r44dUYoy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XCcE42l3_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_r44dUYoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_r44dUYoy, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vqWAHW4H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vwl98h9m_sendMessage);
  cSwitchcase_bd10QEZS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_BW35vMN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_r44dUYoy, 0, m, &cDelay_r44dUYoy_sendMessage);
}

void Heavy_vSwell::cCast_XCcE42l3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_r44dUYoy, 0, m, &cDelay_r44dUYoy_sendMessage);
}

void Heavy_vSwell::cPack_mEmPhTVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DLgRODwV_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_0afNgaTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mgyKa9gT_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_81SP9OHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_2WWNLFOg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_bRi72p7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_mEmPhTVR, 0, m, &cPack_mEmPhTVR_sendMessage);
}

void Heavy_vSwell::cCast_QNrnMHEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0afNgaTX, 0, m, &cVar_0afNgaTX_sendMessage);
}

void Heavy_vSwell::cMsg_mgyKa9gT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_b5IV56ZP, 0, m, NULL);
}

void Heavy_vSwell::cMsg_DLgRODwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_b5IV56ZP, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_bd10QEZS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xE9SEbbD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xE9SEbbD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dle2F0Ch, 1, m, &cDelay_dle2F0Ch_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jipcNarP_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_dle2F0Ch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dle2F0Ch, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GVaQfQOR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SYzekOGs_sendMessage);
  cSwitchcase_UjWbr2GM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_xE9SEbbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dle2F0Ch, 0, m, &cDelay_dle2F0Ch_sendMessage);
}

void Heavy_vSwell::cCast_jipcNarP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dle2F0Ch, 0, m, &cDelay_dle2F0Ch_sendMessage);
}

void Heavy_vSwell::cPack_F3m35Oqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_15APKRV5_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_0dshU9ZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VxNh9D2f_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_LnCTyobU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_bd10QEZS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_vqWAHW4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0dshU9ZO, 0, m, &cVar_0dshU9ZO_sendMessage);
}

void Heavy_vSwell::cCast_Vwl98h9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_F3m35Oqi, 0, m, &cPack_F3m35Oqi_sendMessage);
}

void Heavy_vSwell::cMsg_VxNh9D2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_b5IV56ZP, 0, m, NULL);
}

void Heavy_vSwell::cMsg_15APKRV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_b5IV56ZP, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_UjWbr2GM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_g5V4m0js_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_g5V4m0js_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GYNHBu58, 1, m, &cDelay_GYNHBu58_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sLpbrSJ5_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_GYNHBu58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GYNHBu58, m);
}

void Heavy_vSwell::cMsg_g5V4m0js_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GYNHBu58, 0, m, &cDelay_GYNHBu58_sendMessage);
}

void Heavy_vSwell::cCast_sLpbrSJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GYNHBu58, 0, m, &cDelay_GYNHBu58_sendMessage);
}

void Heavy_vSwell::cPack_fGqFTfRn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rc0933G1_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_8H8W6XcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PON5o6WF_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_vpyL4C0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_UjWbr2GM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_SYzekOGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_fGqFTfRn, 0, m, &cPack_fGqFTfRn_sendMessage);
}

void Heavy_vSwell::cCast_GVaQfQOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8H8W6XcH, 0, m, &cVar_8H8W6XcH_sendMessage);
}

void Heavy_vSwell::cMsg_PON5o6WF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_b5IV56ZP, 0, m, NULL);
}

void Heavy_vSwell::cMsg_rc0933G1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_b5IV56ZP, 0, m, NULL);
}

void Heavy_vSwell::cIf_GpmcPwAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k2bJPA8s_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kT9LOLoj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSwitchcase_zdMpcDgt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t5PFfYJF_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_t5PFfYJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k2bJPA8s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kT9LOLoj_sendMessage);
}

void Heavy_vSwell::cVar_hz9mze6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FHL46nRY_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_uU4GjvJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_fGqFTfRn, 1, m, &cPack_fGqFTfRn_sendMessage);
}

void Heavy_vSwell::cMsg_IAhgLkTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oZmzGJzR_sendMessage);
}

void Heavy_vSwell::cSystem_oZmzGJzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qAK11QYY, HV_BINOP_MULTIPLY, 1, m, &cBinop_qAK11QYY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_B1eydAF4, HV_BINOP_MULTIPLY, 1, m, &cBinop_B1eydAF4_sendMessage);
}

void Heavy_vSwell::cSwitchcase_RxGMpEmL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cMsg_0pw6Gyd9_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_0pw6Gyd9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5UCRB0ZS_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_TbHKkOba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TbHKkOba, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TbHKkOba, 0, m, &cDelay_TbHKkOba_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mmOchhs5, 0, m, &cVar_mmOchhs5_sendMessage);
}

void Heavy_vSwell::cCast_5UCRB0ZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0pw6Gyd9_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TbHKkOba, 0, m, &cDelay_TbHKkOba_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mmOchhs5, 0, m, &cVar_mmOchhs5_sendMessage);
}

void Heavy_vSwell::cMsg_ZKfbvxBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sugID6bY_sendMessage);
}

void Heavy_vSwell::cSystem_sugID6bY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_lvkhDA0h_sendMessage);
}

void Heavy_vSwell::cVar_FU81aU7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9gRYNbUi, HV_BINOP_MULTIPLY, 0, m, &cBinop_9gRYNbUi_sendMessage);
}

void Heavy_vSwell::cMsg_0pw6Gyd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TbHKkOba, 0, m, &cDelay_TbHKkOba_sendMessage);
}

void Heavy_vSwell::cBinop_2BdTRWOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TbHKkOba, 2, m, &cDelay_TbHKkOba_sendMessage);
}

void Heavy_vSwell::cBinop_lvkhDA0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9gRYNbUi, HV_BINOP_MULTIPLY, 1, m, &cBinop_9gRYNbUi_sendMessage);
}

void Heavy_vSwell::cBinop_9gRYNbUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_2BdTRWOD_sendMessage);
}

void Heavy_vSwell::cVar_mmOchhs5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c10UW9fu, HV_BINOP_SUBTRACT, 0, m, &cBinop_c10UW9fu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_DqwGXizW_sendMessage);
}

void Heavy_vSwell::cSwitchcase_gBBwuEOc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9UmgKxm1_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z2Q8MRtN_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_9UmgKxm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_47P141NJ, 0, m, &cVar_47P141NJ_sendMessage);
}

void Heavy_vSwell::cCast_Z2Q8MRtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h1AWe7FJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aaZOenAm_sendMessage);
}

void Heavy_vSwell::cSwitchcase_11tJWRWR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ey5NPiU5, 0, m, &cSlice_ey5NPiU5_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rOBujmsW, 0, m, &cSlice_rOBujmsW_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4vYWyVmR_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_kaJlBnjY, 0, m, &cSlice_kaJlBnjY_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_aIV0koXO, 0, m, &cSlice_aIV0koXO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XNd4NX1B_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dvF6NAno_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_ey5NPiU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_DGlZZLK4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_DGlZZLK4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_rOBujmsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nkLOJymm_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WMinYrPC_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nkLOJymm_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WMinYrPC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_MrKm7HQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kOrPRM0k_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zRl8WOTR_sendMessage);
}

void Heavy_vSwell::cVar_tHaSnMd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_J9jcvQtg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_J9jcvQtg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zUoal7ws_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_qAK11QYY, HV_BINOP_MULTIPLY, 0, m, &cBinop_qAK11QYY_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_vwU2zUkj, HV_BINOP_DIVIDE, 1, m, &cBinop_vwU2zUkj_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_FU81aU7I, 0, m, &cVar_FU81aU7I_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cCast_zUoal7ws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UtFhBMs6_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_neRa3rhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ctFA6d7M, HV_BINOP_SUBTRACT, 1, m, &cBinop_ctFA6d7M_sendMessage);
}

void Heavy_vSwell::cVar_FKg6jxRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_47P141NJ, 0, m, &cVar_47P141NJ_sendMessage);
}

void Heavy_vSwell::cVar_47P141NJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_brBXyLko, HV_BINOP_ADD, 0, m, &cBinop_brBXyLko_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YyC8wfyP, HV_BINOP_ADD, 0, m, &cBinop_YyC8wfyP_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_UGiNWJ5x, m);
}

void Heavy_vSwell::cSlice_kaJlBnjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kOrPRM0k_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zRl8WOTR_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_aIV0koXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ert9x4MV_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9zVu6sE_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_WfYtBGfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mmOchhs5, 1, m, &cVar_mmOchhs5_sendMessage);
}

void Heavy_vSwell::cBinop_B1eydAF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_WfYtBGfy_sendMessage);
}

void Heavy_vSwell::cBinop_qAK11QYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_E89oLATf_sendMessage);
}

void Heavy_vSwell::cBinop_E89oLATf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c10UW9fu, HV_BINOP_SUBTRACT, 1, m, &cBinop_c10UW9fu_sendMessage);
}

void Heavy_vSwell::cBinop_c10UW9fu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mmOchhs5, 1, m, &cVar_mmOchhs5_sendMessage);
}

void Heavy_vSwell::cMsg_CzGwBF8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_RxGMpEmL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_DJiwzFEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_RxGMpEmL_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YyC8wfyP, HV_BINOP_ADD, 1, m, &cBinop_YyC8wfyP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_brBXyLko, HV_BINOP_ADD, 1, m, &cBinop_brBXyLko_sendMessage);
}

void Heavy_vSwell::cBinop_DqwGXizW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gBBwuEOc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_brBXyLko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_47P141NJ, 1, m, &cVar_47P141NJ_sendMessage);
}

void Heavy_vSwell::cBinop_vwU2zUkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ah074Epm, HV_BINOP_DIVIDE, 1, m, &cBinop_Ah074Epm_sendMessage);
}

void Heavy_vSwell::cBinop_Ah074Epm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YyC8wfyP, HV_BINOP_ADD, 1, m, &cBinop_YyC8wfyP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_brBXyLko, HV_BINOP_ADD, 1, m, &cBinop_brBXyLko_sendMessage);
}

void Heavy_vSwell::cCast_kOrPRM0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B1eydAF4, HV_BINOP_MULTIPLY, 0, m, &cBinop_B1eydAF4_sendMessage);
}

void Heavy_vSwell::cCast_zRl8WOTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vwU2zUkj, HV_BINOP_DIVIDE, 0, m, &cBinop_vwU2zUkj_sendMessage);
}

void Heavy_vSwell::cCast_n9zVu6sE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ctFA6d7M, HV_BINOP_SUBTRACT, 0, m, &cBinop_ctFA6d7M_sendMessage);
}

void Heavy_vSwell::cCast_Ert9x4MV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FKg6jxRk, 1, m, &cVar_FKg6jxRk_sendMessage);
}

void Heavy_vSwell::cCast_aaZOenAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FKg6jxRk, 0, m, &cVar_FKg6jxRk_sendMessage);
}

void Heavy_vSwell::cCast_h1AWe7FJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DJiwzFEE_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_YyC8wfyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_neRa3rhM, 0, m, &cVar_neRa3rhM_sendMessage);
}

void Heavy_vSwell::cMsg_DGlZZLK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_RxGMpEmL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_p3GG1Z5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_MrKm7HQ8, 1, m, &cVar_MrKm7HQ8_sendMessage);
}

void Heavy_vSwell::cMsg_UtFhBMs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qAK11QYY, HV_BINOP_MULTIPLY, 0, m, &cBinop_qAK11QYY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vwU2zUkj, HV_BINOP_DIVIDE, 1, m, &cBinop_vwU2zUkj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FU81aU7I, 0, m, &cVar_FU81aU7I_sendMessage);
}

void Heavy_vSwell::cCast_WMinYrPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wUPhnfJH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YyC8wfyP, HV_BINOP_ADD, 0, m, &cBinop_YyC8wfyP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_47P141NJ, 1, m, &cVar_47P141NJ_sendMessage);
}

void Heavy_vSwell::cCast_nkLOJymm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DGlZZLK4_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_ctFA6d7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ah074Epm, HV_BINOP_DIVIDE, 0, m, &cBinop_Ah074Epm_sendMessage);
}

void Heavy_vSwell::cCast_wUPhnfJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DJiwzFEE_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_XNd4NX1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CzGwBF8T_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_4vYWyVmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MrKm7HQ8, 0, m, &cVar_MrKm7HQ8_sendMessage);
}

void Heavy_vSwell::cCast_dvF6NAno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p3GG1Z5T_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cSwitchcase_ukdL3LOz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BvoL93JH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BvoL93JH_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KNFxKcip, 1, m, &cDelay_KNFxKcip_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XOgQKBzB_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_KNFxKcip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KNFxKcip, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QNrnMHEC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bRi72p7y_sendMessage);
  cSwitchcase_2WWNLFOg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_BvoL93JH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KNFxKcip, 0, m, &cDelay_KNFxKcip_sendMessage);
}

void Heavy_vSwell::cCast_XOgQKBzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KNFxKcip, 0, m, &cDelay_KNFxKcip_sendMessage);
}

void Heavy_vSwell::cVar_5Pi7RuRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t6gJZF4r, HV_BINOP_MULTIPLY, 0, m, &cBinop_t6gJZF4r_sendMessage);
}

void Heavy_vSwell::cMsg_1D5KMBUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_H9yqImAy_sendMessage);
}

void Heavy_vSwell::cSystem_H9yqImAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yd46uy8k_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_t6gJZF4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ARYhqELV_sendMessage);
}

void Heavy_vSwell::cBinop_hztu5xu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t6gJZF4r, HV_BINOP_MULTIPLY, 1, m, &cBinop_t6gJZF4r_sendMessage);
}

void Heavy_vSwell::cMsg_Yd46uy8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hztu5xu1_sendMessage);
}

void Heavy_vSwell::cBinop_ARYhqELV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_6n2tz0YG_sendMessage);
}

void Heavy_vSwell::cBinop_6n2tz0YG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_CXwPNZop_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wAyLWKS7, m);
}

void Heavy_vSwell::cBinop_CXwPNZop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ku0ubf0E, m);
}

void Heavy_vSwell::cMsg_57NlJ3kY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1wyjPau0_sendMessage);
}

void Heavy_vSwell::cSystem_1wyjPau0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VHZCGmJR_sendMessage);
}

void Heavy_vSwell::cDelay_WxZLKTTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WxZLKTTw, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yYL6K3er, 0, m, &cDelay_yYL6K3er_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WxZLKTTw, 0, m, &cDelay_WxZLKTTw_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_QgCBhOiQ, 1, m, NULL);
}

void Heavy_vSwell::cDelay_yYL6K3er_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yYL6K3er, m);
  cMsg_ABWAZzHP_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_Mnq9QZJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xLQjd3yB_sendMessage(_c, 0, m);
}

void Heavy_vSwell::hTable_O064EXeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PvuhsfpN_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WxZLKTTw, 2, m, &cDelay_WxZLKTTw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ALRI8hoR_sendMessage);
}

void Heavy_vSwell::cMsg_xLQjd3yB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_O064EXeZ, 0, m, &hTable_O064EXeZ_sendMessage);
}

void Heavy_vSwell::cBinop_VHZCGmJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Mnq9QZJR_sendMessage);
}

void Heavy_vSwell::cMsg_ABWAZzHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_O064EXeZ, 0, m, &hTable_O064EXeZ_sendMessage);
}

void Heavy_vSwell::cCast_ALRI8hoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WxZLKTTw, 0, m, &cDelay_WxZLKTTw_sendMessage);
}

void Heavy_vSwell::cMsg_PvuhsfpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_yYL6K3er, 2, m, &cDelay_yYL6K3er_sendMessage);
}

void Heavy_vSwell::cTabhead_wWdFyyIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c0jOExdW, HV_BINOP_SUBTRACT, 0, m, &cBinop_c0jOExdW_sendMessage);
}

void Heavy_vSwell::cMsg_4Mv7ZnbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_to9HZZiH_sendMessage);
}

void Heavy_vSwell::cSystem_to9HZZiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_F90XoVB9_sendMessage);
}

void Heavy_vSwell::cVar_9OE6WqUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NtXExQwO_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cDelay_TvNIk3jT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TvNIk3jT, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LHPvtudF, 0, m, &cDelay_LHPvtudF_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_VnaxrgnU, 0, m, &sTabread_VnaxrgnU_sendMessage);
}

void Heavy_vSwell::cDelay_LHPvtudF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LHPvtudF, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_VnaxrgnU, 0, m, &sTabread_VnaxrgnU_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LHPvtudF, 0, m, &cDelay_LHPvtudF_sendMessage);
}

void Heavy_vSwell::sTabread_VnaxrgnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_duxBREDs, HV_BINOP_SUBTRACT, 0, m, &cBinop_duxBREDs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_Dj87N7KJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4DS5XSNo, HV_BINOP_MAX, 0, m, &cBinop_4DS5XSNo_sendMessage);
}

void Heavy_vSwell::cBinop_F90XoVB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dj87N7KJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_Dj87N7KJ_sendMessage);
}

void Heavy_vSwell::cBinop_c0jOExdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5ZQGzpjp_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_VnaxrgnU, 0, m, &sTabread_VnaxrgnU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5ZrStAW5_sendMessage);
}

void Heavy_vSwell::cSystem_VzYR3kC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_duxBREDs, HV_BINOP_SUBTRACT, 1, m, &cBinop_duxBREDs_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LHPvtudF, 2, m, &cDelay_LHPvtudF_sendMessage);
}

void Heavy_vSwell::cMsg_NtXExQwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VzYR3kC3_sendMessage);
}

void Heavy_vSwell::cMsg_5ZQGzpjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TvNIk3jT, 0, m, &cDelay_TvNIk3jT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LHPvtudF, 0, m, &cDelay_LHPvtudF_sendMessage);
}

void Heavy_vSwell::cMsg_K9FdLG1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_4DS5XSNo, HV_BINOP_MAX, 1, m, &cBinop_4DS5XSNo_sendMessage);
}

void Heavy_vSwell::cBinop_4DS5XSNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c0jOExdW, HV_BINOP_SUBTRACT, 1, m, &cBinop_c0jOExdW_sendMessage);
}

void Heavy_vSwell::cCast_5ZrStAW5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TvNIk3jT, 0, m, &cDelay_TvNIk3jT_sendMessage);
}

void Heavy_vSwell::cBinop_YszZ3ihe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TvNIk3jT, 2, m, &cDelay_TvNIk3jT_sendMessage);
}

void Heavy_vSwell::cBinop_duxBREDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YszZ3ihe_sendMessage);
}

void Heavy_vSwell::cCast_woOkdSyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9OE6WqUq, 0, m, &cVar_9OE6WqUq_sendMessage);
  cMsg_4Mv7ZnbP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_wWdFyyIT, 0, m, &cTabhead_wWdFyyIT_sendMessage);
}

void Heavy_vSwell::cUnop_1lHaoY64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Qw5G04LZ, m);
}

void Heavy_vSwell::cCast_k2bJPA8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FPVMvBu4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_hz9mze6C, 0, m, &cVar_hz9mze6C_sendMessage);
}

void Heavy_vSwell::cCast_kT9LOLoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ukdL3LOz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_xVkIQwHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nHxsItMr, HV_BINOP_SUBTRACT, 0, m, &cBinop_nHxsItMr_sendMessage);
}

void Heavy_vSwell::cCast_MhwkTUAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fodKGBqC, 0, m, &cVar_fodKGBqC_sendMessage);
}

void Heavy_vSwell::cBinop_nHxsItMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TCKRK1RG, 0, m, &cVar_TCKRK1RG_sendMessage);
}

void Heavy_vSwell::cSend_FPVMvBu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_M83nwdAM_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_U4oBNoTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zdMpcDgt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_lG8Y5fZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_11tJWRWR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_FHL46nRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b5IV56ZP, 0, m, NULL);
}

void Heavy_vSwell::cSend_BoP5ia3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_h7uV2Id5_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_nZrKu4H7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KNFxKcip, 1, m, &cDelay_KNFxKcip_sendMessage);
}

void Heavy_vSwell::cBinop_uFSV4ird_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_1lHaoY64_sendMessage);
}

void Heavy_vSwell::cReceive_27wz3v6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nHxsItMr, HV_BINOP_SUBTRACT, 1, m, &cBinop_nHxsItMr_sendMessage);
}

void Heavy_vSwell::cReceive_9yf2Rxwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZKfbvxBd_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_FU81aU7I, 0, m, &cVar_FU81aU7I_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CKy0vAry, 0, m, &cVar_CKy0vAry_sendMessage);
  cMsg_IAhgLkTg_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_neRa3rhM, 0, m, &cVar_neRa3rhM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tHaSnMd4, 0, m, &cVar_tHaSnMd4_sendMessage);
  cMsg_1D5KMBUL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5Pi7RuRw, 0, m, &cVar_5Pi7RuRw_sendMessage);
  cMsg_57NlJ3kY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uU4GjvJM, 0, m, &cVar_uU4GjvJM_sendMessage);
  cMsg_K9FdLG1l_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_9OE6WqUq, 0, m, &cVar_9OE6WqUq_sendMessage);
  cMsg_4Mv7ZnbP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_wWdFyyIT, 0, m, &cTabhead_wWdFyyIT_sendMessage);
}

void Heavy_vSwell::cReceive_lXagAWpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_0uhnzd30, 0, m, &cSlice_0uhnzd30_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_QQi0FUQY, 0, m, &cSlice_QQi0FUQY_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_scwGuJq0, 0, m, &cSlice_scwGuJq0_sendMessage);
}

void Heavy_vSwell::cReceive_FqUWDLcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mOW3O0Ta, m);
}

void Heavy_vSwell::cReceive_M83nwdAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_81SP9OHf_sendMessage(_c, 0, m);
  cMsg_LnCTyobU_sendMessage(_c, 0, m);
  cMsg_vpyL4C0T_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_Yuzz8M6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xVkIQwHH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MhwkTUAJ_sendMessage);
}

void Heavy_vSwell::cReceive_oUHH4I0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k2bJPA8s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kT9LOLoj_sendMessage);
}

void Heavy_vSwell::cReceive_2D7N9oVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GpmcPwAQ, 1, m, &cIf_GpmcPwAQ_sendMessage);
}

void Heavy_vSwell::cReceive_3t4tPjfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0dshU9ZO, 1, m, &cVar_0dshU9ZO_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_mEmPhTVR, 1, m, &cPack_mEmPhTVR_sendMessage);
}

void Heavy_vSwell::cReceive_blyGw3hm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_mEmPhTVR, 2, m, &cPack_mEmPhTVR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_r44dUYoy, 1, m, &cDelay_r44dUYoy_sendMessage);
}

void Heavy_vSwell::cReceive_9fxRJWtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_F3m35Oqi, 1, m, &cPack_F3m35Oqi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8H8W6XcH, 1, m, &cVar_8H8W6XcH_sendMessage);
}

void Heavy_vSwell::cReceive_c5OTESlQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_F3m35Oqi, 2, m, &cPack_F3m35Oqi_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dle2F0Ch, 1, m, &cDelay_dle2F0Ch_sendMessage);
}

void Heavy_vSwell::cReceive_DNtXTRti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_fGqFTfRn, 2, m, &cPack_fGqFTfRn_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GYNHBu58, 1, m, &cDelay_GYNHBu58_sendMessage);
}

void Heavy_vSwell::cReceive_h7uV2Id5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uU4GjvJM, 1, m, &cVar_uU4GjvJM_sendMessage);
  cMsg_lG8Y5fZM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_hz9mze6C, 1, m, &cVar_hz9mze6C_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0afNgaTX, 1, m, &cVar_0afNgaTX_sendMessage);
}

void Heavy_vSwell::cReceive_GenGUKZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BoP5ia3p_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_slhNiKL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_nZrKu4H7_sendMessage);
}

void Heavy_vSwell::cReceive_3TeoH8xW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_uFSV4ird_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_b9qmX7ee, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwell::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4;

  // input and output vars
  hv_bufferf_t O0;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_QgCBhOiQ, VIf(I0));
    __hv_tabread_f(&sTabread_VnaxrgnU, VOf(Bf0));
    __hv_varread_f(&sVarf_wAyLWKS7, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_ku0ubf0E, VOf(Bf2));
    __hv_rpole_f(&sRPole_r2MOTexs, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_b9qmX7ee, VOf(Bf1));
    __hv_varread_f(&sVarf_Qw5G04LZ, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf3));
    __hv_gt_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_sqrt_f(VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_DOLGpdX5, VIf(Bf3), &sEnv_DOLGpdX5_sendMessage);
    __hv_line_f(&sLine_b5IV56ZP, VOf(Bf3));
    __hv_varread_f(&sVarf_mOW3O0Ta, VOf(Bf1));
    __hv_pow_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_UGiNWJ5x, VOf(Bf3));
    __hv_max_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed
}

int Heavy_vSwell::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 1 channel(s)
  float **const bOut = &outputBuffers;

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwell::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 1 channel(s)
  float *const bOut = outputBuffers;

  int n = processInline(bIn, bOut, n4);

  

  return n;
}
