/**
 * Copyright (c) 2023 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELL_HPP_
#define _HEAVY_CONTEXT_VSWELL_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvMath.h"
#include "HvSignalRPole.h"
#include "HvControlUnop.h"
#include "HvSignalVar.h"
#include "HvSignalLine.h"
#include "HvControlSlice.h"
#include "HvControlIf.h"
#include "HvSignalDel1.h"
#include "HvControlBinop.h"
#include "HvSignalEnvelope.h"
#include "HvSignalTabwrite.h"
#include "HvControlSystem.h"
#include "HvControlCast.h"
#include "HvControlPack.h"
#include "HvTable.h"
#include "HvControlVar.h"
#include "HvSignalTabread.h"
#include "HvControlTabhead.h"
#include "HvControlDelay.h"

class Heavy_vSwell : public HeavyContext {

 public:
  Heavy_vSwell(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwell();

  const char *getName() override { return "vSwell"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 1; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_BY_AUDIO_ON = 0xE7A7BB75, // Trigger_by_Audio_ON
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_DOLGpdX5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GDEXSwXF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_M9M1ycfn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_0JPTBcHK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OlalfsVZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ANJ9cktm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WBtsTXIm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wPFUfY8k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y0MXYUyq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VHnqtLtv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N05pE5wR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ji0fs6uB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_2m3y0thE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_AGoygqfK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GOwP3g4a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_yX48XYgl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1qJKZWM8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cb6MwJx2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DyANiW7g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b62uZ9qb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6UhvGjdK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qPx6sKni_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_jsM9VquE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_miEi7JCY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9QtFjKcG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_k1ms7VvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7dthoAs6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fodKGBqC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TCKRK1RG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2r1ppDwb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7q852oDM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bzTsfiah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_buYAKPhm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_0uhnzd30_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_QQi0FUQY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_scwGuJq0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CKy0vAry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_RsEotKYI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2w4EsuYA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Zsus1rnG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cmNZBMC0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_io6rJh9B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_yqL1o1zQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cXTVmzn0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mpJN0Ufb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d48MlnsP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vcN5ARU8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y1xwSXYf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bQu6acLf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oTuNvNja_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_62aJ0NFI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CSAhyzs9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fN9qgyGJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2WWNLFOg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_r44dUYoy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BW35vMN9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XCcE42l3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_mEmPhTVR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0afNgaTX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_81SP9OHf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bRi72p7y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QNrnMHEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mgyKa9gT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DLgRODwV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bd10QEZS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_dle2F0Ch_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xE9SEbbD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jipcNarP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_F3m35Oqi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0dshU9ZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LnCTyobU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vqWAHW4H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Vwl98h9m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VxNh9D2f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_15APKRV5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_UjWbr2GM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_GYNHBu58_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g5V4m0js_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sLpbrSJ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_fGqFTfRn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8H8W6XcH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vpyL4C0T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SYzekOGs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GVaQfQOR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PON5o6WF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rc0933G1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GpmcPwAQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zdMpcDgt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_t5PFfYJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hz9mze6C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uU4GjvJM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IAhgLkTg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oZmzGJzR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_RxGMpEmL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_TbHKkOba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5UCRB0ZS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZKfbvxBd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_sugID6bY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FU81aU7I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0pw6Gyd9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2BdTRWOD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lvkhDA0h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9gRYNbUi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mmOchhs5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gBBwuEOc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_9UmgKxm1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z2Q8MRtN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_11tJWRWR_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ey5NPiU5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_rOBujmsW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MrKm7HQ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tHaSnMd4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_J9jcvQtg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_zUoal7ws_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_neRa3rhM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FKg6jxRk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_47P141NJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_kaJlBnjY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_aIV0koXO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WfYtBGfy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B1eydAF4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qAK11QYY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E89oLATf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c10UW9fu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CzGwBF8T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DJiwzFEE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DqwGXizW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_brBXyLko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vwU2zUkj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ah074Epm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kOrPRM0k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zRl8WOTR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n9zVu6sE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ert9x4MV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aaZOenAm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h1AWe7FJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YyC8wfyP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DGlZZLK4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p3GG1Z5T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UtFhBMs6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WMinYrPC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nkLOJymm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ctFA6d7M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wUPhnfJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XNd4NX1B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4vYWyVmR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dvF6NAno_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ukdL3LOz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_KNFxKcip_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BvoL93JH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XOgQKBzB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5Pi7RuRw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1D5KMBUL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_H9yqImAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t6gJZF4r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hztu5xu1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yd46uy8k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ARYhqELV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6n2tz0YG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CXwPNZop_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_57NlJ3kY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1wyjPau0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_WxZLKTTw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_yYL6K3er_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mnq9QZJR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_O064EXeZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xLQjd3yB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VHZCGmJR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ABWAZzHP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ALRI8hoR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PvuhsfpN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_wWdFyyIT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4Mv7ZnbP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_to9HZZiH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9OE6WqUq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TvNIk3jT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_LHPvtudF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_VnaxrgnU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dj87N7KJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F90XoVB9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c0jOExdW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VzYR3kC3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NtXExQwO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5ZQGzpjp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K9FdLG1l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4DS5XSNo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5ZrStAW5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YszZ3ihe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_duxBREDs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_woOkdSyz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1lHaoY64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k2bJPA8s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kT9LOLoj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xVkIQwHH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MhwkTUAJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nHxsItMr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_FPVMvBu4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U4oBNoTS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lG8Y5fZM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FHL46nRY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_BoP5ia3p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nZrKu4H7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uFSV4ird_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_27wz3v6o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9yf2Rxwm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lXagAWpq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FqUWDLcg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_M83nwdAM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Yuzz8M6Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oUHH4I0a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2D7N9oVU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3t4tPjfG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_blyGw3hm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9fxRJWtv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_c5OTESlQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DNtXTRti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_h7uV2Id5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GenGUKZ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_slhNiKL0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3TeoH8xW_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_QgCBhOiQ;
  SignalTabread sTabread_VnaxrgnU;
  SignalRPole sRPole_r2MOTexs;
  SignalEnvelope sEnv_DOLGpdX5;
  SignalLine sLine_b5IV56ZP;
  ControlSlice cSlice_M9M1ycfn;
  ControlSlice cSlice_0JPTBcHK;
  ControlVar cVar_OlalfsVZ;
  ControlIf cIf_ANJ9cktm;
  ControlBinop cBinop_y0MXYUyq;
  ControlSlice cSlice_2m3y0thE;
  ControlSlice cSlice_AGoygqfK;
  ControlVar cVar_GOwP3g4a;
  ControlIf cIf_yX48XYgl;
  ControlBinop cBinop_DyANiW7g;
  ControlVar cVar_fodKGBqC;
  ControlVar cVar_TCKRK1RG;
  ControlBinop cBinop_2r1ppDwb;
  ControlBinop cBinop_7q852oDM;
  ControlSlice cSlice_0uhnzd30;
  ControlSlice cSlice_QQi0FUQY;
  ControlSlice cSlice_scwGuJq0;
  ControlVar cVar_CKy0vAry;
  ControlIf cIf_Zsus1rnG;
  ControlBinop cBinop_cmNZBMC0;
  ControlIf cIf_io6rJh9B;
  ControlIf cIf_yqL1o1zQ;
  ControlIf cIf_cXTVmzn0;
  ControlIf cIf_mpJN0Ufb;
  ControlBinop cBinop_d48MlnsP;
  ControlBinop cBinop_vcN5ARU8;
  ControlBinop cBinop_Y1xwSXYf;
  ControlBinop cBinop_fN9qgyGJ;
  ControlDelay cDelay_r44dUYoy;
  ControlPack cPack_mEmPhTVR;
  ControlVar cVar_0afNgaTX;
  ControlDelay cDelay_dle2F0Ch;
  ControlPack cPack_F3m35Oqi;
  ControlVar cVar_0dshU9ZO;
  ControlDelay cDelay_GYNHBu58;
  ControlPack cPack_fGqFTfRn;
  ControlVar cVar_8H8W6XcH;
  ControlIf cIf_GpmcPwAQ;
  ControlVar cVar_hz9mze6C;
  ControlVar cVar_uU4GjvJM;
  SignalVarf sVarf_UGiNWJ5x;
  ControlDelay cDelay_TbHKkOba;
  ControlVar cVar_FU81aU7I;
  ControlBinop cBinop_2BdTRWOD;
  ControlBinop cBinop_lvkhDA0h;
  ControlBinop cBinop_9gRYNbUi;
  ControlVar cVar_mmOchhs5;
  ControlSlice cSlice_ey5NPiU5;
  ControlSlice cSlice_rOBujmsW;
  ControlVar cVar_MrKm7HQ8;
  ControlVar cVar_tHaSnMd4;
  ControlVar cVar_neRa3rhM;
  ControlVar cVar_FKg6jxRk;
  ControlVar cVar_47P141NJ;
  ControlSlice cSlice_kaJlBnjY;
  ControlSlice cSlice_aIV0koXO;
  ControlBinop cBinop_WfYtBGfy;
  ControlBinop cBinop_B1eydAF4;
  ControlBinop cBinop_qAK11QYY;
  ControlBinop cBinop_E89oLATf;
  ControlBinop cBinop_c10UW9fu;
  ControlBinop cBinop_DqwGXizW;
  ControlBinop cBinop_brBXyLko;
  ControlBinop cBinop_vwU2zUkj;
  ControlBinop cBinop_Ah074Epm;
  ControlBinop cBinop_YyC8wfyP;
  ControlBinop cBinop_ctFA6d7M;
  ControlDelay cDelay_KNFxKcip;
  ControlVar cVar_5Pi7RuRw;
  ControlBinop cBinop_t6gJZF4r;
  ControlBinop cBinop_hztu5xu1;
  SignalVarf sVarf_ku0ubf0E;
  ControlBinop cBinop_ARYhqELV;
  ControlBinop cBinop_6n2tz0YG;
  ControlBinop cBinop_CXwPNZop;
  SignalVarf sVarf_wAyLWKS7;
  ControlDelay cDelay_WxZLKTTw;
  ControlDelay cDelay_yYL6K3er;
  ControlBinop cBinop_Mnq9QZJR;
  HvTable hTable_O064EXeZ;
  ControlBinop cBinop_VHZCGmJR;
  ControlTabhead cTabhead_wWdFyyIT;
  ControlVar cVar_9OE6WqUq;
  ControlDelay cDelay_TvNIk3jT;
  ControlDelay cDelay_LHPvtudF;
  ControlBinop cBinop_Dj87N7KJ;
  ControlBinop cBinop_F90XoVB9;
  ControlBinop cBinop_c0jOExdW;
  ControlBinop cBinop_4DS5XSNo;
  ControlBinop cBinop_YszZ3ihe;
  ControlBinop cBinop_duxBREDs;
  ControlBinop cBinop_nHxsItMr;
  ControlBinop cBinop_U4oBNoTS;
  ControlBinop cBinop_nZrKu4H7;
  ControlBinop cBinop_uFSV4ird;
  SignalVarf sVarf_mOW3O0Ta;
  SignalVarf sVarf_Qw5G04LZ;
  SignalVarf sVarf_b9qmX7ee;
};

#endif // _HEAVY_CONTEXT_VSWELL_HPP_
