/**
 * Copyright (c) 2023 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwellST.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwellST *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwellST_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwellST_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwellST_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwellST();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwellST::Heavy_vSwellST(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_6hEv8R5K, &hTable_QWNZ7Trb);
  numBytes += sTabwrite_init(&sTabwrite_6Knp049X, &hTable_GvIXzuBq);
  numBytes += sRPole_init(&sRPole_QocMYeYp);
  numBytes += sEnv_init(&sEnv_xdVMDuWg, 1024, 512);
  numBytes += sTabread_init(&sTabread_ktGZNN6U, &hTable_QWNZ7Trb, true);
  numBytes += sLine_init(&sLine_uxMlJ4Ry);
  numBytes += sTabread_init(&sTabread_qiJlEa8S, &hTable_GvIXzuBq, true);
  numBytes += cSlice_init(&cSlice_4tR6Ucc1, 1, -1);
  numBytes += cSlice_init(&cSlice_NDrx77se, 1, -1);
  numBytes += cVar_init_f(&cVar_2SbiyHIw, 0.0f);
  numBytes += cIf_init(&cIf_dvICGyzO, false);
  numBytes += cBinop_init(&cBinop_lXbfT3S6, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_n5pWFPsg, 1, -1);
  numBytes += cSlice_init(&cSlice_JAZkYXRk, 1, -1);
  numBytes += cVar_init_f(&cVar_rB7nctbM, 0.0f);
  numBytes += cIf_init(&cIf_69ca0X2M, false);
  numBytes += cBinop_init(&cBinop_vyrH7UgR, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_v4wK8I2U, 0.0f);
  numBytes += cVar_init_f(&cVar_IG8MyORW, 0.0f);
  numBytes += cBinop_init(&cBinop_LPGd9Wo5, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_cKYpiEOx, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_6ocuvdpn, 2, 1);
  numBytes += cSlice_init(&cSlice_nv80hxEA, 1, 1);
  numBytes += cSlice_init(&cSlice_Gd840jKT, 0, 1);
  numBytes += cVar_init_f(&cVar_xOilWbmY, 0.0f);
  numBytes += cIf_init(&cIf_XwjaFgdN, false);
  numBytes += cIf_init(&cIf_ehBajvB3, false);
  numBytes += cIf_init(&cIf_dVKAFWuk, false);
  numBytes += cIf_init(&cIf_4JHJN7tu, false);
  numBytes += cIf_init(&cIf_E3Pr7X5m, false);
  numBytes += cBinop_init(&cBinop_Lar0tjta, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_Gvy1KFF8, 10.0f);
  numBytes += cPack_init(&cPack_uxvzSbwZ, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_x5oyPXoY, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_DZoex5ji, 10.0f);
  numBytes += cPack_init(&cPack_HMAeiLyu, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_uuBG7vbV, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_UPfXvNu9, 10.0f);
  numBytes += cPack_init(&cPack_PH4cz58b, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_6ZPGUrtu, 1e-07f);
  numBytes += cVar_init_f(&cVar_2cqFPHxc, 1e-07f);
  numBytes += cVar_init_f(&cVar_odQFW33Y, 1e-07f);
  numBytes += sVarf_init(&sVarf_8XBk1Crf, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_Ci7S647D, 0.0f);
  numBytes += cVar_init_f(&cVar_CXigSuFN, 20.0f);
  numBytes += cBinop_init(&cBinop_jgEx8nWw, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_yPVqXsXb, 0.0f);
  numBytes += cSlice_init(&cSlice_HGjJPcsX, 1, -1);
  numBytes += cSlice_init(&cSlice_rGJOoz1P, 1, -1);
  numBytes += cVar_init_f(&cVar_cyQEEeot, 0.0f);
  numBytes += cVar_init_f(&cVar_IBDZuRKz, 20.0f);
  numBytes += cVar_init_f(&cVar_5h8LBD96, 0.0f);
  numBytes += cVar_init_f(&cVar_kmyecMqf, 0.0f);
  numBytes += cVar_init_f(&cVar_OrvPiStU, 0.0f);
  numBytes += cSlice_init(&cSlice_aMZcr1Q4, 1, 1);
  numBytes += cSlice_init(&cSlice_WO8q89id, 0, 1);
  numBytes += cBinop_init(&cBinop_BNojRXiW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_noq1MYYa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kuAkDD8X, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_yjT7uuw5, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_4hfIu5e7, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_XIIVFUL1, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_yIoIABU7, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_bnsO5iPZ, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_aplaCRfa, 5.0f);
  numBytes += cVar_init_f(&cVar_fec8xFRj, 500.0f);
  numBytes += cBinop_init(&cBinop_YSC3cPan, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_JD1IEQXP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_D2OudhzC, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_oSwcelFU, 0.0f);
  numBytes += cDelay_init(this, &cDelay_HXNO8gxp, 0.0f);
  numBytes += hTable_init(&hTable_QWNZ7Trb, 256);
  numBytes += cTabhead_init(&cTabhead_TRt4VbRj, &hTable_QWNZ7Trb);
  numBytes += cVar_init_s(&cVar_YGzIUjpf, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_eYJ1LQbt, 8.0f);
  numBytes += cDelay_init(this, &cDelay_N9ADO3Es, 0.0f);
  numBytes += cBinop_init(&cBinop_lbvM0B1K, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_jITSHbt9, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_rE6VIVhR, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_aD4EycNU, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_wR2fMRVt, 0.0f);
  numBytes += cDelay_init(this, &cDelay_sWj5W4hV, 0.0f);
  numBytes += hTable_init(&hTable_GvIXzuBq, 256);
  numBytes += cTabhead_init(&cTabhead_gzplWncc, &hTable_GvIXzuBq);
  numBytes += cVar_init_s(&cVar_BfI4ZM9v, "del-1001-swell2");
  numBytes += cDelay_init(this, &cDelay_fvj4lfqC, 8.0f);
  numBytes += cDelay_init(this, &cDelay_JcpYlKom, 0.0f);
  numBytes += cBinop_init(&cBinop_bth73G6Y, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_vFUGKRJ5, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Gculyg5B, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_rrr4hWGD, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_nYGBRNId, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_ndvCxhV5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4DYMWuzt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6sVmEuaa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OFzBHyAH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bgbk4JYq, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwellST::~Heavy_vSwellST() {
  sEnv_free(&sEnv_xdVMDuWg);
  cPack_free(&cPack_uxvzSbwZ);
  cPack_free(&cPack_HMAeiLyu);
  cPack_free(&cPack_PH4cz58b);
  hTable_free(&hTable_QWNZ7Trb);
  hTable_free(&hTable_GvIXzuBq);
}

HvTable *Heavy_vSwellST::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_QWNZ7Trb; // del-1001-swell
    case 0x505A9C79: return &hTable_GvIXzuBq; // del-1001-swell2
    default: return nullptr;
  }
}

void Heavy_vSwellST::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Y3CNjgpm_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gQw8hFEg_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1ekgMYvx_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BaT66pG1_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9LwwgnMj_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ytFup6Lz_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8JFyrcLQ_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iS19VY5V_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CbLvJTnt_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VklodYdh_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cASsC2zL_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1XVr9yJa_sendMessage);
      break;
    }
    case 0x4E6E7C40: { // Trigger_Left
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nQEPHzT6_sendMessage);
      break;
    }
    case 0xB181ABB6: { // Trigger_Right
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ag0ELANM_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R9xJEcN5_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8TAWzdj2_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XULpRBLl_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nRCuU9OC_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwellST::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 20.0f;
        info->maxVal = 90.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_Left";
        info->hash = 0x4E6E7C40;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "Trigger_Right";
        info->hash = 0xB181ABB6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 14;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwellST::sEnv_xdVMDuWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LPGd9Wo5, HV_BINOP_GREATER_THAN, 0, m, &cBinop_LPGd9Wo5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cKYpiEOx, HV_BINOP_LESS_THAN, 0, m, &cBinop_cKYpiEOx_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_yUYh85K3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4tR6Ucc1, 0, m, &cSlice_4tR6Ucc1_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NDrx77se, 0, m, &cSlice_NDrx77se_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7iz36FEV_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GMe3PxIu_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_4tR6Ucc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_2SbiyHIw, 0, m, &cVar_2SbiyHIw_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_2SbiyHIw, 0, m, &cVar_2SbiyHIw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_NDrx77se_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_lXbfT3S6, HV_BINOP_NEQ, 1, m, &cBinop_lXbfT3S6_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_2SbiyHIw, 1, m, &cVar_2SbiyHIw_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_lXbfT3S6, HV_BINOP_NEQ, 1, m, &cBinop_lXbfT3S6_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_2SbiyHIw, 1, m, &cVar_2SbiyHIw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_2SbiyHIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OZa1nz2y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_dvICGyzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l0hNSxqZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YMZD4CY9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_YMZD4CY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2SbiyHIw, 0, m, &cVar_2SbiyHIw_sendMessage);
}

void Heavy_vSwellST::cCast_l0hNSxqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lXbfT3S6, HV_BINOP_NEQ, 1, m, &cBinop_lXbfT3S6_sendMessage);
}

void Heavy_vSwellST::cBinop_lXbfT3S6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dvICGyzO, 1, m, &cIf_dvICGyzO_sendMessage);
}

void Heavy_vSwellST::cCast_GMe3PxIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dvICGyzO, 0, m, &cIf_dvICGyzO_sendMessage);
}

void Heavy_vSwellST::cCast_7iz36FEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lXbfT3S6, HV_BINOP_NEQ, 0, m, &cBinop_lXbfT3S6_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_Xh9HAq4W_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_n5pWFPsg, 0, m, &cSlice_n5pWFPsg_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JAZkYXRk, 0, m, &cSlice_JAZkYXRk_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Uk8oHPEI_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rPj9Orj0_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_n5pWFPsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_rB7nctbM, 0, m, &cVar_rB7nctbM_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_rB7nctbM, 0, m, &cVar_rB7nctbM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_JAZkYXRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_vyrH7UgR, HV_BINOP_NEQ, 1, m, &cBinop_vyrH7UgR_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_rB7nctbM, 1, m, &cVar_rB7nctbM_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_vyrH7UgR, HV_BINOP_NEQ, 1, m, &cBinop_vyrH7UgR_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_rB7nctbM, 1, m, &cVar_rB7nctbM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_rB7nctbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9EwQWe3t_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_69ca0X2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kMonFFJx_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z5F9R4hO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_kMonFFJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vyrH7UgR, HV_BINOP_NEQ, 1, m, &cBinop_vyrH7UgR_sendMessage);
}

void Heavy_vSwellST::cCast_Z5F9R4hO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rB7nctbM, 0, m, &cVar_rB7nctbM_sendMessage);
}

void Heavy_vSwellST::cBinop_vyrH7UgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_69ca0X2M, 1, m, &cIf_69ca0X2M_sendMessage);
}

void Heavy_vSwellST::cCast_rPj9Orj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_69ca0X2M, 0, m, &cIf_69ca0X2M_sendMessage);
}

void Heavy_vSwellST::cCast_Uk8oHPEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vyrH7UgR, HV_BINOP_NEQ, 0, m, &cBinop_vyrH7UgR_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_OZa1nz2y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gmlk1Oo3_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ATkVdbZN_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_Gmlk1Oo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IG8MyORW, 0, m, &cVar_IG8MyORW_sendMessage);
}

void Heavy_vSwellST::cCast_ATkVdbZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4gw248Aj_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L5tRgdmx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pCOp6cts_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_9EwQWe3t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PgngBI7c_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vwMuIb6x_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_PgngBI7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v4wK8I2U, 0, m, &cVar_v4wK8I2U_sendMessage);
}

void Heavy_vSwellST::cCast_vwMuIb6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kVWVR2nB_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_v4wK8I2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LPGd9Wo5, HV_BINOP_GREATER_THAN, 1, m, &cBinop_LPGd9Wo5_sendMessage);
}

void Heavy_vSwellST::cVar_IG8MyORW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cKYpiEOx, HV_BINOP_LESS_THAN, 1, m, &cBinop_cKYpiEOx_sendMessage);
}

void Heavy_vSwellST::cBinop_LPGd9Wo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_yUYh85K3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_cKYpiEOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Xh9HAq4W_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_4gw248Aj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LPGd9Wo5, HV_BINOP_GREATER_THAN, 1, m, &cBinop_LPGd9Wo5_sendMessage);
}

void Heavy_vSwellST::cMsg_kVWVR2nB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cKYpiEOx, HV_BINOP_LESS_THAN, 1, m, &cBinop_cKYpiEOx_sendMessage);
}

void Heavy_vSwellST::cSlice_6ocuvdpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_FimRQuIs_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_nv80hxEA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_4JHJN7tu, 0, m, &cIf_4JHJN7tu_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_ehBajvB3, 0, m, &cIf_ehBajvB3_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_Gd840jKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_E3Pr7X5m, 0, m, &cIf_E3Pr7X5m_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_dVKAFWuk, 0, m, &cIf_dVKAFWuk_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_xOilWbmY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eT2KAv76_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_XwjaFgdN, 0, m, &cIf_XwjaFgdN_sendMessage);
}

void Heavy_vSwellST::cUnop_wb1FIg1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LkJnds2S_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lar0tjta, HV_BINOP_EQ, 1, m, &cBinop_Lar0tjta_sendMessage);
}

void Heavy_vSwellST::cUnop_aPO6qr1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LkJnds2S_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lar0tjta, HV_BINOP_EQ, 1, m, &cBinop_Lar0tjta_sendMessage);
}

void Heavy_vSwellST::cIf_XwjaFgdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_aPO6qr1y_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_wb1FIg1G_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_eT2KAv76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XwjaFgdN, 1, m, &cIf_XwjaFgdN_sendMessage);
}

void Heavy_vSwellST::cIf_ehBajvB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kYVLu3ub_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_dVKAFWuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_4JHJN7tu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kYVLu3ub_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_E3Pr7X5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_FimRQuIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lar0tjta, HV_BINOP_EQ, 0, m, &cBinop_Lar0tjta_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_MsIXg03C_sendMessage);
}

void Heavy_vSwellST::cBinop_LkJnds2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x4c5krMf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EvThHgWJ_sendMessage);
}

void Heavy_vSwellST::cBinop_Lar0tjta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bew63kll_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eYZxuOce_sendMessage);
}

void Heavy_vSwellST::cCast_Bew63kll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ehBajvB3, 1, m, &cIf_ehBajvB3_sendMessage);
}

void Heavy_vSwellST::cCast_eYZxuOce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E3Pr7X5m, 1, m, &cIf_E3Pr7X5m_sendMessage);
}

void Heavy_vSwellST::cCast_x4c5krMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4JHJN7tu, 1, m, &cIf_4JHJN7tu_sendMessage);
}

void Heavy_vSwellST::cCast_EvThHgWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dVKAFWuk, 1, m, &cIf_dVKAFWuk_sendMessage);
}

void Heavy_vSwellST::cBinop_MsIXg03C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwellST::cSwitchcase_OsqSEalJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_X15wWgHU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_X15wWgHU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Gvy1KFF8, 1, m, &cDelay_Gvy1KFF8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P7MMKVWL_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_Gvy1KFF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Gvy1KFF8, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WS8rV3Wi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Yvqo6CWZ_sendMessage);
  cSwitchcase_CPiqC2RF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_X15wWgHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Gvy1KFF8, 0, m, &cDelay_Gvy1KFF8_sendMessage);
}

void Heavy_vSwellST::cCast_P7MMKVWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Gvy1KFF8, 0, m, &cDelay_Gvy1KFF8_sendMessage);
}

void Heavy_vSwellST::cPack_uxvzSbwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iDu9xfx6_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_x5oyPXoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ym8o5zDP_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_nVpzX0hs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_OsqSEalJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_N4Iymcdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_uxvzSbwZ, 0, m, &cPack_uxvzSbwZ_sendMessage);
}

void Heavy_vSwellST::cCast_uDjsKiFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x5oyPXoY, 0, m, &cVar_x5oyPXoY_sendMessage);
}

void Heavy_vSwellST::cMsg_ym8o5zDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_uxMlJ4Ry, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_iDu9xfx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_uxMlJ4Ry, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_CPiqC2RF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_A3lQo3mu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_A3lQo3mu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_DZoex5ji, 1, m, &cDelay_DZoex5ji_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SGCv1ORl_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_DZoex5ji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DZoex5ji, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8i2BLMU8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ufuI8oaW_sendMessage);
  cSwitchcase_Z5Hhkzm9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_A3lQo3mu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_DZoex5ji, 0, m, &cDelay_DZoex5ji_sendMessage);
}

void Heavy_vSwellST::cCast_SGCv1ORl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DZoex5ji, 0, m, &cDelay_DZoex5ji_sendMessage);
}

void Heavy_vSwellST::cPack_HMAeiLyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Svs6Bbfk_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_uuBG7vbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lp341xeR_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_jqWjAvKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_CPiqC2RF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_WS8rV3Wi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uuBG7vbV, 0, m, &cVar_uuBG7vbV_sendMessage);
}

void Heavy_vSwellST::cCast_Yvqo6CWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_HMAeiLyu, 0, m, &cPack_HMAeiLyu_sendMessage);
}

void Heavy_vSwellST::cMsg_lp341xeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_uxMlJ4Ry, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_Svs6Bbfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_uxMlJ4Ry, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_Z5Hhkzm9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_grzOiafU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_grzOiafU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UPfXvNu9, 1, m, &cDelay_UPfXvNu9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2yRb9tIQ_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_UPfXvNu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UPfXvNu9, m);
}

void Heavy_vSwellST::cMsg_grzOiafU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UPfXvNu9, 0, m, &cDelay_UPfXvNu9_sendMessage);
}

void Heavy_vSwellST::cCast_2yRb9tIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UPfXvNu9, 0, m, &cDelay_UPfXvNu9_sendMessage);
}

void Heavy_vSwellST::cPack_PH4cz58b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_10TsyH2b_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_6ZPGUrtu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EaaMrxvY_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_IizUEyuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_Z5Hhkzm9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_ufuI8oaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_PH4cz58b, 0, m, &cPack_PH4cz58b_sendMessage);
}

void Heavy_vSwellST::cCast_8i2BLMU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6ZPGUrtu, 0, m, &cVar_6ZPGUrtu_sendMessage);
}

void Heavy_vSwellST::cMsg_EaaMrxvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_uxMlJ4Ry, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_10TsyH2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_uxMlJ4Ry, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_oRWdH9MZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZQjICx5u_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_ZQjICx5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L5tRgdmx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pCOp6cts_sendMessage);
}

void Heavy_vSwellST::cVar_2cqFPHxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vy97GqiQ_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_odQFW33Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_PH4cz58b, 1, m, &cPack_PH4cz58b_sendMessage);
}

void Heavy_vSwellST::cMsg_o49cEjtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7xXPo0TP_sendMessage);
}

void Heavy_vSwellST::cSystem_7xXPo0TP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_noq1MYYa, HV_BINOP_MULTIPLY, 1, m, &cBinop_noq1MYYa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BNojRXiW, HV_BINOP_MULTIPLY, 1, m, &cBinop_BNojRXiW_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_jh7RvCSu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cMsg_tgs7yrEp_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_tgs7yrEp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PBBx5wfM_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_Ci7S647D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ci7S647D, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ci7S647D, 0, m, &cDelay_Ci7S647D_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yPVqXsXb, 0, m, &cVar_yPVqXsXb_sendMessage);
}

void Heavy_vSwellST::cCast_PBBx5wfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tgs7yrEp_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ci7S647D, 0, m, &cDelay_Ci7S647D_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yPVqXsXb, 0, m, &cVar_yPVqXsXb_sendMessage);
}

void Heavy_vSwellST::cMsg_5Vrzd2dA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_C5zCRR3X_sendMessage);
}

void Heavy_vSwellST::cSystem_C5zCRR3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IqPSVLHM_sendMessage);
}

void Heavy_vSwellST::cVar_CXigSuFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jgEx8nWw, HV_BINOP_MULTIPLY, 0, m, &cBinop_jgEx8nWw_sendMessage);
}

void Heavy_vSwellST::cMsg_tgs7yrEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ci7S647D, 0, m, &cDelay_Ci7S647D_sendMessage);
}

void Heavy_vSwellST::cBinop_G6dBFoki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ci7S647D, 2, m, &cDelay_Ci7S647D_sendMessage);
}

void Heavy_vSwellST::cBinop_IqPSVLHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jgEx8nWw, HV_BINOP_MULTIPLY, 1, m, &cBinop_jgEx8nWw_sendMessage);
}

void Heavy_vSwellST::cBinop_jgEx8nWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_G6dBFoki_sendMessage);
}

void Heavy_vSwellST::cVar_yPVqXsXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kuAkDD8X, HV_BINOP_SUBTRACT, 0, m, &cBinop_kuAkDD8X_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_C9KQ0VhA_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_H2kddb42_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zgEZHWEN_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sbCZyeJi_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_zgEZHWEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OrvPiStU, 0, m, &cVar_OrvPiStU_sendMessage);
}

void Heavy_vSwellST::cCast_sbCZyeJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1kjIRsQO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cljTBly8_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_KTIjKYoG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HGjJPcsX, 0, m, &cSlice_HGjJPcsX_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rGJOoz1P, 0, m, &cSlice_rGJOoz1P_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7uodlfne_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_aMZcr1Q4, 0, m, &cSlice_aMZcr1Q4_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_WO8q89id, 0, m, &cSlice_WO8q89id_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9OAl3P9G_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JTGcig76_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_HGjJPcsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_FMQp613N_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_FMQp613N_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_rGJOoz1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f3Vdvlqr_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mgs6NqEG_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f3Vdvlqr_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mgs6NqEG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_cyQEEeot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yst86tl9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QmLtAwi0_sendMessage);
}

void Heavy_vSwellST::cVar_IBDZuRKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4L5gualG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_4L5gualG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uGgkSRmO_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_noq1MYYa, HV_BINOP_MULTIPLY, 0, m, &cBinop_noq1MYYa_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_4hfIu5e7, HV_BINOP_DIVIDE, 1, m, &cBinop_4hfIu5e7_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_CXigSuFN, 0, m, &cVar_CXigSuFN_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cCast_uGgkSRmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hwv0OyfG_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_5h8LBD96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bnsO5iPZ, HV_BINOP_SUBTRACT, 1, m, &cBinop_bnsO5iPZ_sendMessage);
}

void Heavy_vSwellST::cVar_kmyecMqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OrvPiStU, 0, m, &cVar_OrvPiStU_sendMessage);
}

void Heavy_vSwellST::cVar_OrvPiStU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yjT7uuw5, HV_BINOP_ADD, 0, m, &cBinop_yjT7uuw5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yIoIABU7, HV_BINOP_ADD, 0, m, &cBinop_yIoIABU7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_8XBk1Crf, m);
}

void Heavy_vSwellST::cSlice_aMZcr1Q4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yst86tl9_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QmLtAwi0_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_WO8q89id_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XjsVvvBm_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrLcquRH_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_BfxxjBHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yPVqXsXb, 1, m, &cVar_yPVqXsXb_sendMessage);
}

void Heavy_vSwellST::cBinop_BNojRXiW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_BfxxjBHs_sendMessage);
}

void Heavy_vSwellST::cBinop_noq1MYYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_iZC7v6L0_sendMessage);
}

void Heavy_vSwellST::cBinop_iZC7v6L0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kuAkDD8X, HV_BINOP_SUBTRACT, 1, m, &cBinop_kuAkDD8X_sendMessage);
}

void Heavy_vSwellST::cBinop_kuAkDD8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yPVqXsXb, 1, m, &cVar_yPVqXsXb_sendMessage);
}

void Heavy_vSwellST::cMsg_SjLpVigf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_jh7RvCSu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_uOTUQisd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_jh7RvCSu_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yIoIABU7, HV_BINOP_ADD, 1, m, &cBinop_yIoIABU7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yjT7uuw5, HV_BINOP_ADD, 1, m, &cBinop_yjT7uuw5_sendMessage);
}

void Heavy_vSwellST::cBinop_C9KQ0VhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_H2kddb42_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_yjT7uuw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OrvPiStU, 1, m, &cVar_OrvPiStU_sendMessage);
}

void Heavy_vSwellST::cBinop_4hfIu5e7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XIIVFUL1, HV_BINOP_DIVIDE, 1, m, &cBinop_XIIVFUL1_sendMessage);
}

void Heavy_vSwellST::cBinop_XIIVFUL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yIoIABU7, HV_BINOP_ADD, 1, m, &cBinop_yIoIABU7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yjT7uuw5, HV_BINOP_ADD, 1, m, &cBinop_yjT7uuw5_sendMessage);
}

void Heavy_vSwellST::cCast_yst86tl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BNojRXiW, HV_BINOP_MULTIPLY, 0, m, &cBinop_BNojRXiW_sendMessage);
}

void Heavy_vSwellST::cCast_QmLtAwi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4hfIu5e7, HV_BINOP_DIVIDE, 0, m, &cBinop_4hfIu5e7_sendMessage);
}

void Heavy_vSwellST::cCast_lrLcquRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bnsO5iPZ, HV_BINOP_SUBTRACT, 0, m, &cBinop_bnsO5iPZ_sendMessage);
}

void Heavy_vSwellST::cCast_XjsVvvBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kmyecMqf, 1, m, &cVar_kmyecMqf_sendMessage);
}

void Heavy_vSwellST::cCast_cljTBly8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kmyecMqf, 0, m, &cVar_kmyecMqf_sendMessage);
}

void Heavy_vSwellST::cCast_1kjIRsQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uOTUQisd_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_yIoIABU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5h8LBD96, 0, m, &cVar_5h8LBD96_sendMessage);
}

void Heavy_vSwellST::cMsg_FMQp613N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_jh7RvCSu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_y49imwya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_cyQEEeot, 1, m, &cVar_cyQEEeot_sendMessage);
}

void Heavy_vSwellST::cMsg_hwv0OyfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_noq1MYYa, HV_BINOP_MULTIPLY, 0, m, &cBinop_noq1MYYa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4hfIu5e7, HV_BINOP_DIVIDE, 1, m, &cBinop_4hfIu5e7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CXigSuFN, 0, m, &cVar_CXigSuFN_sendMessage);
}

void Heavy_vSwellST::cCast_f3Vdvlqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FMQp613N_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_Mgs6NqEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U2S5O0Fn_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yIoIABU7, HV_BINOP_ADD, 0, m, &cBinop_yIoIABU7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OrvPiStU, 1, m, &cVar_OrvPiStU_sendMessage);
}

void Heavy_vSwellST::cBinop_bnsO5iPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XIIVFUL1, HV_BINOP_DIVIDE, 0, m, &cBinop_XIIVFUL1_sendMessage);
}

void Heavy_vSwellST::cCast_U2S5O0Fn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uOTUQisd_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_9OAl3P9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SjLpVigf_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_7uodlfne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cyQEEeot, 0, m, &cVar_cyQEEeot_sendMessage);
}

void Heavy_vSwellST::cCast_JTGcig76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y49imwya_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_pXLCWUP1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  switch (msg_getHash(m, 0)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Utf222Rb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Utf222Rb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_aplaCRfa, 1, m, &cDelay_aplaCRfa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f184LgcP_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_aplaCRfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aplaCRfa, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uDjsKiFF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N4Iymcdc_sendMessage);
  cSwitchcase_OsqSEalJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_Utf222Rb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_aplaCRfa, 0, m, &cDelay_aplaCRfa_sendMessage);
}

void Heavy_vSwellST::cCast_f184LgcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_aplaCRfa, 0, m, &cDelay_aplaCRfa_sendMessage);
}

void Heavy_vSwellST::cVar_fec8xFRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YSC3cPan, HV_BINOP_MULTIPLY, 0, m, &cBinop_YSC3cPan_sendMessage);
}

void Heavy_vSwellST::cMsg_nsZwRkRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_P5qUmh6w_sendMessage);
}

void Heavy_vSwellST::cSystem_P5qUmh6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3QUYq74g_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_YSC3cPan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_u8yDCSzJ_sendMessage);
}

void Heavy_vSwellST::cBinop_M5kb60n3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YSC3cPan, HV_BINOP_MULTIPLY, 1, m, &cBinop_YSC3cPan_sendMessage);
}

void Heavy_vSwellST::cMsg_3QUYq74g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_M5kb60n3_sendMessage);
}

void Heavy_vSwellST::cBinop_u8yDCSzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_bHkWMA40_sendMessage);
}

void Heavy_vSwellST::cBinop_bHkWMA40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_GCoi3tZv_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_D2OudhzC, m);
}

void Heavy_vSwellST::cBinop_GCoi3tZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_JD1IEQXP, m);
}

void Heavy_vSwellST::cMsg_B8rfUTpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oSqzXKw8_sendMessage);
}

void Heavy_vSwellST::cSystem_oSqzXKw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_RczcUaK5_sendMessage);
}

void Heavy_vSwellST::cDelay_oSwcelFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oSwcelFU, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HXNO8gxp, 0, m, &cDelay_HXNO8gxp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oSwcelFU, 0, m, &cDelay_oSwcelFU_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6hEv8R5K, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_HXNO8gxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HXNO8gxp, m);
  cMsg_55lHHxXP_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_WJezyjud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uvJS8Xax_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_QWNZ7Trb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XZNk81Ug_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oSwcelFU, 2, m, &cDelay_oSwcelFU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oPRrkwlr_sendMessage);
}

void Heavy_vSwellST::cMsg_uvJS8Xax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_QWNZ7Trb, 0, m, &hTable_QWNZ7Trb_sendMessage);
}

void Heavy_vSwellST::cBinop_RczcUaK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_WJezyjud_sendMessage);
}

void Heavy_vSwellST::cMsg_55lHHxXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_QWNZ7Trb, 0, m, &hTable_QWNZ7Trb_sendMessage);
}

void Heavy_vSwellST::cCast_oPRrkwlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oSwcelFU, 0, m, &cDelay_oSwcelFU_sendMessage);
}

void Heavy_vSwellST::cMsg_XZNk81Ug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_HXNO8gxp, 2, m, &cDelay_HXNO8gxp_sendMessage);
}

void Heavy_vSwellST::cTabhead_TRt4VbRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jITSHbt9, HV_BINOP_SUBTRACT, 0, m, &cBinop_jITSHbt9_sendMessage);
}

void Heavy_vSwellST::cMsg_AEJG6mSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0nKEfwab_sendMessage);
}

void Heavy_vSwellST::cSystem_0nKEfwab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_DOAaPiDn_sendMessage);
}

void Heavy_vSwellST::cVar_YGzIUjpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JuBCf5qJ_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_eYJ1LQbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eYJ1LQbt, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_N9ADO3Es, 0, m, &cDelay_N9ADO3Es_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ktGZNN6U, 0, m, &sTabread_ktGZNN6U_sendMessage);
}

void Heavy_vSwellST::cDelay_N9ADO3Es_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_N9ADO3Es, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ktGZNN6U, 0, m, &sTabread_ktGZNN6U_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_N9ADO3Es, 0, m, &cDelay_N9ADO3Es_sendMessage);
}

void Heavy_vSwellST::sTabread_ktGZNN6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_aD4EycNU, HV_BINOP_SUBTRACT, 0, m, &cBinop_aD4EycNU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_lbvM0B1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rE6VIVhR, HV_BINOP_MAX, 0, m, &cBinop_rE6VIVhR_sendMessage);
}

void Heavy_vSwellST::cBinop_DOAaPiDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lbvM0B1K, HV_BINOP_MULTIPLY, 0, m, &cBinop_lbvM0B1K_sendMessage);
}

void Heavy_vSwellST::cBinop_jITSHbt9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3wWiV35x_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ktGZNN6U, 0, m, &sTabread_ktGZNN6U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XRAMDuX1_sendMessage);
}

void Heavy_vSwellST::cSystem_DXsFN4DQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aD4EycNU, HV_BINOP_SUBTRACT, 1, m, &cBinop_aD4EycNU_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_N9ADO3Es, 2, m, &cDelay_N9ADO3Es_sendMessage);
}

void Heavy_vSwellST::cMsg_JuBCf5qJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DXsFN4DQ_sendMessage);
}

void Heavy_vSwellST::cMsg_3wWiV35x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_eYJ1LQbt, 0, m, &cDelay_eYJ1LQbt_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_N9ADO3Es, 0, m, &cDelay_N9ADO3Es_sendMessage);
}

void Heavy_vSwellST::cMsg_fXZ7iTWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_rE6VIVhR, HV_BINOP_MAX, 1, m, &cBinop_rE6VIVhR_sendMessage);
}

void Heavy_vSwellST::cBinop_rE6VIVhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jITSHbt9, HV_BINOP_SUBTRACT, 1, m, &cBinop_jITSHbt9_sendMessage);
}

void Heavy_vSwellST::cCast_XRAMDuX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eYJ1LQbt, 0, m, &cDelay_eYJ1LQbt_sendMessage);
}

void Heavy_vSwellST::cBinop_vyVGjgcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eYJ1LQbt, 2, m, &cDelay_eYJ1LQbt_sendMessage);
}

void Heavy_vSwellST::cBinop_aD4EycNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vyVGjgcs_sendMessage);
}

void Heavy_vSwellST::cCast_sXzZyv3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YGzIUjpf, 0, m, &cVar_YGzIUjpf_sendMessage);
  cMsg_AEJG6mSI_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_TRt4VbRj, 0, m, &cTabhead_TRt4VbRj_sendMessage);
}

void Heavy_vSwellST::cMsg_AXNiUod4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Txw0nc60_sendMessage);
}

void Heavy_vSwellST::cSystem_Txw0nc60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_MIBjBNI9_sendMessage);
}

void Heavy_vSwellST::cDelay_wR2fMRVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wR2fMRVt, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sWj5W4hV, 0, m, &cDelay_sWj5W4hV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wR2fMRVt, 0, m, &cDelay_wR2fMRVt_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6Knp049X, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_sWj5W4hV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sWj5W4hV, m);
  cMsg_8L0haBu9_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_zkpIHdKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wqIlrUBh_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_GvIXzuBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nKg9OZLC_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wR2fMRVt, 2, m, &cDelay_wR2fMRVt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_440qJGVc_sendMessage);
}

void Heavy_vSwellST::cMsg_wqIlrUBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_GvIXzuBq, 0, m, &hTable_GvIXzuBq_sendMessage);
}

void Heavy_vSwellST::cBinop_MIBjBNI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_zkpIHdKw_sendMessage);
}

void Heavy_vSwellST::cMsg_8L0haBu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_GvIXzuBq, 0, m, &hTable_GvIXzuBq_sendMessage);
}

void Heavy_vSwellST::cCast_440qJGVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wR2fMRVt, 0, m, &cDelay_wR2fMRVt_sendMessage);
}

void Heavy_vSwellST::cMsg_nKg9OZLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_sWj5W4hV, 2, m, &cDelay_sWj5W4hV_sendMessage);
}

void Heavy_vSwellST::cTabhead_gzplWncc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vFUGKRJ5, HV_BINOP_SUBTRACT, 0, m, &cBinop_vFUGKRJ5_sendMessage);
}

void Heavy_vSwellST::cMsg_D3Xz43Lj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rdmCFpAY_sendMessage);
}

void Heavy_vSwellST::cSystem_rdmCFpAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_n1KO57YL_sendMessage);
}

void Heavy_vSwellST::cVar_BfI4ZM9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gjhq9LPC_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_fvj4lfqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fvj4lfqC, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JcpYlKom, 0, m, &cDelay_JcpYlKom_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qiJlEa8S, 0, m, &sTabread_qiJlEa8S_sendMessage);
}

void Heavy_vSwellST::cDelay_JcpYlKom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JcpYlKom, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qiJlEa8S, 0, m, &sTabread_qiJlEa8S_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JcpYlKom, 0, m, &cDelay_JcpYlKom_sendMessage);
}

void Heavy_vSwellST::sTabread_qiJlEa8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_rrr4hWGD, HV_BINOP_SUBTRACT, 0, m, &cBinop_rrr4hWGD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_bth73G6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gculyg5B, HV_BINOP_MAX, 0, m, &cBinop_Gculyg5B_sendMessage);
}

void Heavy_vSwellST::cBinop_n1KO57YL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bth73G6Y, HV_BINOP_MULTIPLY, 0, m, &cBinop_bth73G6Y_sendMessage);
}

void Heavy_vSwellST::cBinop_vFUGKRJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6g6crHDw_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qiJlEa8S, 0, m, &sTabread_qiJlEa8S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z6uEO1ED_sendMessage);
}

void Heavy_vSwellST::cSystem_VF47UBYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rrr4hWGD, HV_BINOP_SUBTRACT, 1, m, &cBinop_rrr4hWGD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JcpYlKom, 2, m, &cDelay_JcpYlKom_sendMessage);
}

void Heavy_vSwellST::cMsg_Gjhq9LPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VF47UBYe_sendMessage);
}

void Heavy_vSwellST::cMsg_6g6crHDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fvj4lfqC, 0, m, &cDelay_fvj4lfqC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JcpYlKom, 0, m, &cDelay_JcpYlKom_sendMessage);
}

void Heavy_vSwellST::cMsg_gK6wEzM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gculyg5B, HV_BINOP_MAX, 1, m, &cBinop_Gculyg5B_sendMessage);
}

void Heavy_vSwellST::cBinop_Gculyg5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vFUGKRJ5, HV_BINOP_SUBTRACT, 1, m, &cBinop_vFUGKRJ5_sendMessage);
}

void Heavy_vSwellST::cCast_Z6uEO1ED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fvj4lfqC, 0, m, &cDelay_fvj4lfqC_sendMessage);
}

void Heavy_vSwellST::cBinop_rNssdRPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fvj4lfqC, 2, m, &cDelay_fvj4lfqC_sendMessage);
}

void Heavy_vSwellST::cBinop_rrr4hWGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rNssdRPv_sendMessage);
}

void Heavy_vSwellST::cCast_Zo17prse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BfI4ZM9v, 0, m, &cVar_BfI4ZM9v_sendMessage);
  cMsg_D3Xz43Lj_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_gzplWncc, 0, m, &cTabhead_gzplWncc_sendMessage);
}

void Heavy_vSwellST::cUnop_FIwYA5QN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OFzBHyAH, m);
}

void Heavy_vSwellST::cCast_L5tRgdmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VlezTDkE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2cqFPHxc, 0, m, &cVar_2cqFPHxc_sendMessage);
}

void Heavy_vSwellST::cCast_pCOp6cts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pXLCWUP1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_Gs39lXv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v4wK8I2U, 0, m, &cVar_v4wK8I2U_sendMessage);
}

void Heavy_vSwellST::cCast_hmxRLTxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nYGBRNId, HV_BINOP_SUBTRACT, 0, m, &cBinop_nYGBRNId_sendMessage);
}

void Heavy_vSwellST::cBinop_nYGBRNId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IG8MyORW, 0, m, &cVar_IG8MyORW_sendMessage);
}

void Heavy_vSwellST::cSend_VlezTDkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XULpRBLl_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_kYVLu3ub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oRWdH9MZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_Hhm80N0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_KTIjKYoG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_vy97GqiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uxMlJ4Ry, 0, m, NULL);
}

void Heavy_vSwellST::cSend_jgzNJocf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nRCuU9OC_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_gRIoR120_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_aplaCRfa, 1, m, &cDelay_aplaCRfa_sendMessage);
}

void Heavy_vSwellST::cBinop_qcxmYPus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_FIwYA5QN_sendMessage);
}

void Heavy_vSwellST::cReceive_CbLvJTnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nYGBRNId, HV_BINOP_SUBTRACT, 1, m, &cBinop_nYGBRNId_sendMessage);
}

void Heavy_vSwellST::cReceive_R9xJEcN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Vrzd2dA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CXigSuFN, 0, m, &cVar_CXigSuFN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xOilWbmY, 0, m, &cVar_xOilWbmY_sendMessage);
  cMsg_o49cEjtk_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5h8LBD96, 0, m, &cVar_5h8LBD96_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IBDZuRKz, 0, m, &cVar_IBDZuRKz_sendMessage);
  cMsg_nsZwRkRY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fec8xFRj, 0, m, &cVar_fec8xFRj_sendMessage);
  cMsg_B8rfUTpN_sendMessage(_c, 0, m);
  cMsg_AXNiUod4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_odQFW33Y, 0, m, &cVar_odQFW33Y_sendMessage);
  cMsg_fXZ7iTWq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YGzIUjpf, 0, m, &cVar_YGzIUjpf_sendMessage);
  cMsg_AEJG6mSI_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_TRt4VbRj, 0, m, &cTabhead_TRt4VbRj_sendMessage);
  cMsg_gK6wEzM6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BfI4ZM9v, 0, m, &cVar_BfI4ZM9v_sendMessage);
  cMsg_D3Xz43Lj_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_gzplWncc, 0, m, &cTabhead_gzplWncc_sendMessage);
}

void Heavy_vSwellST::cReceive_8TAWzdj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_6ocuvdpn, 0, m, &cSlice_6ocuvdpn_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_nv80hxEA, 0, m, &cSlice_nv80hxEA_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_Gd840jKT, 0, m, &cSlice_Gd840jKT_sendMessage);
}

void Heavy_vSwellST::cReceive_ytFup6Lz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ndvCxhV5, m);
}

void Heavy_vSwellST::cReceive_XULpRBLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nVpzX0hs_sendMessage(_c, 0, m);
  cMsg_jqWjAvKm_sendMessage(_c, 0, m);
  cMsg_IizUEyuA_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_1XVr9yJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L5tRgdmx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pCOp6cts_sendMessage);
}

void Heavy_vSwellST::cReceive_Y3CNjgpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uuBG7vbV, 1, m, &cVar_uuBG7vbV_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_uxvzSbwZ, 1, m, &cPack_uxvzSbwZ_sendMessage);
}

void Heavy_vSwellST::cReceive_gQw8hFEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_uxvzSbwZ, 2, m, &cPack_uxvzSbwZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Gvy1KFF8, 1, m, &cDelay_Gvy1KFF8_sendMessage);
}

void Heavy_vSwellST::cReceive_1ekgMYvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_HMAeiLyu, 1, m, &cPack_HMAeiLyu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6ZPGUrtu, 1, m, &cVar_6ZPGUrtu_sendMessage);
}

void Heavy_vSwellST::cReceive_BaT66pG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_HMAeiLyu, 2, m, &cPack_HMAeiLyu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DZoex5ji, 1, m, &cDelay_DZoex5ji_sendMessage);
}

void Heavy_vSwellST::cReceive_9LwwgnMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_PH4cz58b, 2, m, &cPack_PH4cz58b_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UPfXvNu9, 1, m, &cDelay_UPfXvNu9_sendMessage);
}

void Heavy_vSwellST::cReceive_nRCuU9OC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_odQFW33Y, 1, m, &cVar_odQFW33Y_sendMessage);
  cMsg_Hhm80N0r_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2cqFPHxc, 1, m, &cVar_2cqFPHxc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_x5oyPXoY, 1, m, &cVar_x5oyPXoY_sendMessage);
}

void Heavy_vSwellST::cReceive_8JFyrcLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jgzNJocf_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_cASsC2zL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_gRIoR120_sendMessage);
}

void Heavy_vSwellST::cReceive_nQEPHzT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4DYMWuzt, m);
}

void Heavy_vSwellST::cReceive_Ag0ELANM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6sVmEuaa, m);
}

void Heavy_vSwellST::cReceive_iS19VY5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hmxRLTxd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gs39lXv7_sendMessage);
}

void Heavy_vSwellST::cReceive_VklodYdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qcxmYPus_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bgbk4JYq, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwellST::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_6hEv8R5K, VIf(I0));
    __hv_tabwrite_f(&sTabwrite_6Knp049X, VIf(I1));
    __hv_varread_f(&sVarf_4DYMWuzt, VOf(Bf0));
    __hv_varread_f(&sVarf_6sVmEuaa, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_D2OudhzC, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_JD1IEQXP, VOf(Bf1));
    __hv_rpole_f(&sRPole_QocMYeYp, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_bgbk4JYq, VOf(Bf0));
    __hv_varread_f(&sVarf_OFzBHyAH, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf2));
    __hv_gt_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_sqrt_f(VIf(Bf3), VOf(Bf3));
    __hv_and_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf2), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_xdVMDuWg, VIf(Bf2), &sEnv_xdVMDuWg_sendMessage);
    __hv_tabread_f(&sTabread_ktGZNN6U, VOf(Bf2));
    __hv_line_f(&sLine_uxMlJ4Ry, VOf(Bf0));
    __hv_varread_f(&sVarf_ndvCxhV5, VOf(Bf1));
    __hv_pow_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_8XBk1Crf, VOf(Bf0));
    __hv_max_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_tabread_f(&sTabread_qiJlEa8S, VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed
}

int Heavy_vSwellST::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwellST::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
