/**
 * Copyright (c) 2023 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELLST_HPP_
#define _HEAVY_CONTEXT_VSWELLST_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSlice.h"
#include "HvControlDelay.h"
#include "HvControlTabhead.h"
#include "HvControlCast.h"
#include "HvControlVar.h"
#include "HvControlBinop.h"
#include "HvSignalLine.h"
#include "HvControlSystem.h"
#include "HvControlUnop.h"
#include "HvSignalEnvelope.h"
#include "HvSignalTabwrite.h"
#include "HvSignalDel1.h"
#include "HvSignalTabread.h"
#include "HvSignalRPole.h"
#include "HvControlPack.h"
#include "HvMath.h"
#include "HvControlIf.h"
#include "HvTable.h"
#include "HvSignalVar.h"

class Heavy_vSwellST : public HeavyContext {

 public:
  Heavy_vSwellST(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwellST();

  const char *getName() override { return "vSwellST"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_LEFT = 0x4E6E7C40, // Trigger_Left
        TRIGGER_RIGHT = 0xB181ABB6, // Trigger_Right
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_xdVMDuWg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_yUYh85K3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_4tR6Ucc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_NDrx77se_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2SbiyHIw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dvICGyzO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YMZD4CY9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l0hNSxqZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lXbfT3S6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GMe3PxIu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7iz36FEV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Xh9HAq4W_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_n5pWFPsg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_JAZkYXRk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rB7nctbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_69ca0X2M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kMonFFJx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z5F9R4hO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vyrH7UgR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rPj9Orj0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Uk8oHPEI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OZa1nz2y_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_Gmlk1Oo3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ATkVdbZN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9EwQWe3t_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_PgngBI7c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vwMuIb6x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_v4wK8I2U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IG8MyORW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LPGd9Wo5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cKYpiEOx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4gw248Aj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kVWVR2nB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_6ocuvdpn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_nv80hxEA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_Gd840jKT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xOilWbmY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_wb1FIg1G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_aPO6qr1y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XwjaFgdN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eT2KAv76_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ehBajvB3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dVKAFWuk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4JHJN7tu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_E3Pr7X5m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FimRQuIs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LkJnds2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lar0tjta_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Bew63kll_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eYZxuOce_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x4c5krMf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EvThHgWJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MsIXg03C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OsqSEalJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Gvy1KFF8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X15wWgHU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P7MMKVWL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_uxvzSbwZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_x5oyPXoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nVpzX0hs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N4Iymcdc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uDjsKiFF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ym8o5zDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iDu9xfx6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CPiqC2RF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_DZoex5ji_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A3lQo3mu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SGCv1ORl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_HMAeiLyu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uuBG7vbV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jqWjAvKm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WS8rV3Wi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Yvqo6CWZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lp341xeR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Svs6Bbfk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Z5Hhkzm9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_UPfXvNu9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_grzOiafU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2yRb9tIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_PH4cz58b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6ZPGUrtu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IizUEyuA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ufuI8oaW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8i2BLMU8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EaaMrxvY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_10TsyH2b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oRWdH9MZ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_ZQjICx5u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2cqFPHxc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_odQFW33Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o49cEjtk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7xXPo0TP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jh7RvCSu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Ci7S647D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PBBx5wfM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5Vrzd2dA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_C5zCRR3X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CXigSuFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tgs7yrEp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G6dBFoki_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IqPSVLHM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jgEx8nWw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yPVqXsXb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_H2kddb42_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_zgEZHWEN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sbCZyeJi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_KTIjKYoG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_HGjJPcsX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_rGJOoz1P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cyQEEeot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IBDZuRKz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4L5gualG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_uGgkSRmO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5h8LBD96_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kmyecMqf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OrvPiStU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_aMZcr1Q4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_WO8q89id_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BfxxjBHs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BNojRXiW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_noq1MYYa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iZC7v6L0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kuAkDD8X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SjLpVigf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uOTUQisd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C9KQ0VhA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yjT7uuw5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4hfIu5e7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XIIVFUL1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yst86tl9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QmLtAwi0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lrLcquRH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XjsVvvBm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cljTBly8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1kjIRsQO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yIoIABU7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FMQp613N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y49imwya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hwv0OyfG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f3Vdvlqr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mgs6NqEG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bnsO5iPZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U2S5O0Fn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9OAl3P9G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7uodlfne_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JTGcig76_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pXLCWUP1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_aplaCRfa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Utf222Rb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f184LgcP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fec8xFRj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nsZwRkRY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_P5qUmh6w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YSC3cPan_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M5kb60n3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3QUYq74g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u8yDCSzJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bHkWMA40_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GCoi3tZv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B8rfUTpN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oSqzXKw8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oSwcelFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_HXNO8gxp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WJezyjud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_QWNZ7Trb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uvJS8Xax_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RczcUaK5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_55lHHxXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oPRrkwlr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XZNk81Ug_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_TRt4VbRj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AEJG6mSI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0nKEfwab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YGzIUjpf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_eYJ1LQbt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_N9ADO3Es_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_ktGZNN6U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lbvM0B1K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DOAaPiDn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jITSHbt9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_DXsFN4DQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JuBCf5qJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3wWiV35x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fXZ7iTWq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rE6VIVhR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XRAMDuX1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vyVGjgcs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aD4EycNU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sXzZyv3w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AXNiUod4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Txw0nc60_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_wR2fMRVt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sWj5W4hV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zkpIHdKw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_GvIXzuBq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wqIlrUBh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MIBjBNI9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8L0haBu9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_440qJGVc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nKg9OZLC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_gzplWncc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D3Xz43Lj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rdmCFpAY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BfI4ZM9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_fvj4lfqC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_JcpYlKom_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_qiJlEa8S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bth73G6Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n1KO57YL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vFUGKRJ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VF47UBYe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gjhq9LPC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6g6crHDw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gK6wEzM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gculyg5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z6uEO1ED_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rNssdRPv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rrr4hWGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Zo17prse_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_FIwYA5QN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L5tRgdmx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pCOp6cts_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Gs39lXv7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hmxRLTxd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nYGBRNId_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VlezTDkE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kYVLu3ub_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Hhm80N0r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vy97GqiQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_jgzNJocf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gRIoR120_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qcxmYPus_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CbLvJTnt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_R9xJEcN5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8TAWzdj2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ytFup6Lz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XULpRBLl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1XVr9yJa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Y3CNjgpm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gQw8hFEg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1ekgMYvx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BaT66pG1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9LwwgnMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nRCuU9OC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8JFyrcLQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cASsC2zL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nQEPHzT6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ag0ELANM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iS19VY5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VklodYdh_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_6hEv8R5K;
  SignalTabwrite sTabwrite_6Knp049X;
  SignalRPole sRPole_QocMYeYp;
  SignalEnvelope sEnv_xdVMDuWg;
  SignalTabread sTabread_ktGZNN6U;
  SignalLine sLine_uxMlJ4Ry;
  SignalTabread sTabread_qiJlEa8S;
  ControlSlice cSlice_4tR6Ucc1;
  ControlSlice cSlice_NDrx77se;
  ControlVar cVar_2SbiyHIw;
  ControlIf cIf_dvICGyzO;
  ControlBinop cBinop_lXbfT3S6;
  ControlSlice cSlice_n5pWFPsg;
  ControlSlice cSlice_JAZkYXRk;
  ControlVar cVar_rB7nctbM;
  ControlIf cIf_69ca0X2M;
  ControlBinop cBinop_vyrH7UgR;
  ControlVar cVar_v4wK8I2U;
  ControlVar cVar_IG8MyORW;
  ControlBinop cBinop_LPGd9Wo5;
  ControlBinop cBinop_cKYpiEOx;
  ControlSlice cSlice_6ocuvdpn;
  ControlSlice cSlice_nv80hxEA;
  ControlSlice cSlice_Gd840jKT;
  ControlVar cVar_xOilWbmY;
  ControlIf cIf_XwjaFgdN;
  ControlBinop cBinop_eT2KAv76;
  ControlIf cIf_ehBajvB3;
  ControlIf cIf_dVKAFWuk;
  ControlIf cIf_4JHJN7tu;
  ControlIf cIf_E3Pr7X5m;
  ControlBinop cBinop_FimRQuIs;
  ControlBinop cBinop_LkJnds2S;
  ControlBinop cBinop_Lar0tjta;
  ControlBinop cBinop_MsIXg03C;
  ControlDelay cDelay_Gvy1KFF8;
  ControlPack cPack_uxvzSbwZ;
  ControlVar cVar_x5oyPXoY;
  ControlDelay cDelay_DZoex5ji;
  ControlPack cPack_HMAeiLyu;
  ControlVar cVar_uuBG7vbV;
  ControlDelay cDelay_UPfXvNu9;
  ControlPack cPack_PH4cz58b;
  ControlVar cVar_6ZPGUrtu;
  ControlVar cVar_2cqFPHxc;
  ControlVar cVar_odQFW33Y;
  SignalVarf sVarf_8XBk1Crf;
  ControlDelay cDelay_Ci7S647D;
  ControlVar cVar_CXigSuFN;
  ControlBinop cBinop_G6dBFoki;
  ControlBinop cBinop_IqPSVLHM;
  ControlBinop cBinop_jgEx8nWw;
  ControlVar cVar_yPVqXsXb;
  ControlSlice cSlice_HGjJPcsX;
  ControlSlice cSlice_rGJOoz1P;
  ControlVar cVar_cyQEEeot;
  ControlVar cVar_IBDZuRKz;
  ControlVar cVar_5h8LBD96;
  ControlVar cVar_kmyecMqf;
  ControlVar cVar_OrvPiStU;
  ControlSlice cSlice_aMZcr1Q4;
  ControlSlice cSlice_WO8q89id;
  ControlBinop cBinop_BfxxjBHs;
  ControlBinop cBinop_BNojRXiW;
  ControlBinop cBinop_noq1MYYa;
  ControlBinop cBinop_iZC7v6L0;
  ControlBinop cBinop_kuAkDD8X;
  ControlBinop cBinop_C9KQ0VhA;
  ControlBinop cBinop_yjT7uuw5;
  ControlBinop cBinop_4hfIu5e7;
  ControlBinop cBinop_XIIVFUL1;
  ControlBinop cBinop_yIoIABU7;
  ControlBinop cBinop_bnsO5iPZ;
  ControlDelay cDelay_aplaCRfa;
  ControlVar cVar_fec8xFRj;
  ControlBinop cBinop_YSC3cPan;
  ControlBinop cBinop_M5kb60n3;
  SignalVarf sVarf_JD1IEQXP;
  ControlBinop cBinop_u8yDCSzJ;
  ControlBinop cBinop_bHkWMA40;
  ControlBinop cBinop_GCoi3tZv;
  SignalVarf sVarf_D2OudhzC;
  ControlDelay cDelay_oSwcelFU;
  ControlDelay cDelay_HXNO8gxp;
  ControlBinop cBinop_WJezyjud;
  HvTable hTable_QWNZ7Trb;
  ControlBinop cBinop_RczcUaK5;
  ControlTabhead cTabhead_TRt4VbRj;
  ControlVar cVar_YGzIUjpf;
  ControlDelay cDelay_eYJ1LQbt;
  ControlDelay cDelay_N9ADO3Es;
  ControlBinop cBinop_lbvM0B1K;
  ControlBinop cBinop_DOAaPiDn;
  ControlBinop cBinop_jITSHbt9;
  ControlBinop cBinop_rE6VIVhR;
  ControlBinop cBinop_vyVGjgcs;
  ControlBinop cBinop_aD4EycNU;
  ControlDelay cDelay_wR2fMRVt;
  ControlDelay cDelay_sWj5W4hV;
  ControlBinop cBinop_zkpIHdKw;
  HvTable hTable_GvIXzuBq;
  ControlBinop cBinop_MIBjBNI9;
  ControlTabhead cTabhead_gzplWncc;
  ControlVar cVar_BfI4ZM9v;
  ControlDelay cDelay_fvj4lfqC;
  ControlDelay cDelay_JcpYlKom;
  ControlBinop cBinop_bth73G6Y;
  ControlBinop cBinop_n1KO57YL;
  ControlBinop cBinop_vFUGKRJ5;
  ControlBinop cBinop_Gculyg5B;
  ControlBinop cBinop_rNssdRPv;
  ControlBinop cBinop_rrr4hWGD;
  ControlBinop cBinop_nYGBRNId;
  ControlBinop cBinop_kYVLu3ub;
  ControlBinop cBinop_gRIoR120;
  ControlBinop cBinop_qcxmYPus;
  SignalVarf sVarf_ndvCxhV5;
  SignalVarf sVarf_4DYMWuzt;
  SignalVarf sVarf_6sVmEuaa;
  SignalVarf sVarf_OFzBHyAH;
  SignalVarf sVarf_bgbk4JYq;
};

#endif // _HEAVY_CONTEXT_VSWELLST_HPP_
